@@ -18,9 +18,17 @@
  */
 
 #include <iostream>
+#include <algorithm>
 #include "constellation.h"
+#include "hip_star_mgr.h"
+#include "hip_star.h"
 
-bool Constellation::gravity_label = false;
+bool Constellation::gravityLabel = false;
+
+Vec3f Constellation::lineColor = Vec3f(.4,.4,.8);
+Vec3f Constellation::labelColor = Vec3f(.4,.4,.8);
+Vec3f Constellation::boundaryColor = Vec3f(0.8,0.3,0.3);
+bool Constellation::singleSelected = false;
 
 Constellation::Constellation() : asterism(NULL), art_tex(NULL)
 {
@@ -30,41 +38,43 @@ Constellation::~Constellation()
 {   
 	if (asterism) delete[] asterism;
     asterism = NULL;
+    
 	if (art_tex) delete art_tex;
 	art_tex = NULL;
 }
 
-
 // Read Constellation data record and grab cartesian positions of stars
 // returns false if can't parse record
-bool Constellation::read(const string& record, Hip_Star_mgr * _VouteCeleste)
+bool Constellation::read(const string& record, HipStarMgr * _VouteCeleste)
 {   
 	unsigned int HP;
 
-	short_name[0] = 0;
+	abbreviation.clear();
 	nb_segments = 0;
 
 	std::istringstream istr(record);
-	if (!(istr >> short_name >> nb_segments)) return false;
+	if (!(istr >> abbreviation >> nb_segments)) return false;
 		
 	// make short_name uppercase for case insensitive searches
-	for(int a=0; a<3; a++) short_name[a] = ::toupper(short_name[a]);
+	transform(abbreviation.begin(),abbreviation.end(), abbreviation.begin(), ::toupper);
 
-    asterism = new Hip_Star*[nb_segments*2];
+    asterism = new HipStar*[nb_segments*2];
     for (unsigned int i=0;i<nb_segments*2;++i)
     {
 		HP = 0;
         istr >> HP;
 		if(HP == 0)
 		{
-			return(false);
+			delete [] asterism;
+			return false;
 		}
 
-        asterism[i]=_VouteCeleste->search(HP);
+        asterism[i]=_VouteCeleste->searchHP(HP);
 		if (!asterism[i])
 		{
-			printf("Error in Constellation %s asterism : can't find star HP=%d\n",name.c_str(),HP);
-			return(false);
+			cout << "Error in Constellation " << abbreviation << " asterism : can't find star HP= " << HP << endl;
+			delete [] asterism;
+			return false;
 		}
     }
 
@@ -73,34 +83,28 @@ bool Constellation::read(const string& record, Hip_Star_mgr * _VouteCeleste)
 		XYZname+=(*asterism[ii]).XYZ;
     }
     XYZname*=1./(nb_segments*2);
+
 	return true;
 }
 
 
-// Draw the Constellation lines
-void Constellation::draw(Projector* prj, const Vec3f& lines_color) const
-{
-	glDisable(GL_TEXTURE_2D);
-    glDisable(GL_BLEND);
-    prj->set_orthographic_projection();	// set 2D coordinate
-
-	draw_optim(prj, lines_color);
-	
-	prj->reset_perspective_projection();
-}
-
-
 // Draw the lines for the Constellation using the coords of the stars
-// (optimized for use thru the class Constellation_mgr only)
-void Constellation::draw_optim(Projector* prj, const Vec3f& lines_color) const
+// (optimized for use thru the class ConstellationMgr only)
+void Constellation::draw_optim(Projector* prj) const
 {
-	if(!line_fader.get_interstate()) return;
-	glColor3fv(lines_color*line_fader.get_interstate());
+	if(!line_fader.getInterstate()) return;
+
+	glDisable(GL_TEXTURE_2D);
+	glEnable(GL_BLEND);	
+	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA); // Normal transparency mode
+
+	glColor4f(lineColor[0], lineColor[1], lineColor[2], line_fader.getInterstate());
+
 	Vec3d star1;
 	Vec3d star2;
     for(unsigned int i=0;i<nb_segments;++i)
     {
-		if(prj->project_prec_earth_equ_line_check(asterism[2*i]->XYZ,star1,asterism[2*i+1]->XYZ,star2) ) 
+		if(prj->project_j2000_line_check(asterism[2*i]->XYZ,star1,asterism[2*i+1]->XYZ,star2) ) 
 		{
 			glBegin(GL_LINES);
 			glVertex2f(star1[0],star1[1]);
@@ -110,20 +114,20 @@ void Constellation::draw_optim(Projector* prj, const Vec3f& lines_color) const
 	}
 }
 
-
 // Draw the name
-void Constellation::draw_name(s_font * constfont, Projector* prj, Vec3f color) const
+void Constellation::draw_name(s_font *constfont, Projector* prj) const
 {
-	if(!name_fader.get_interstate()) return;
-	glColor3fv(color*name_fader.get_interstate());
-	gravity_label ? prj->print_gravity180(constfont, XYname[0], XYname[1], name, 1, -constfont->getStrLen(name)/2) :
-	constfont->print(XYname[0]-constfont->getStrLen(name)/2, XYname[1], name);
+	if(!name_fader.getInterstate()) return;
+	glColor4f(labelColor[0], labelColor[1], labelColor[2], name_fader.getInterstate());
+	prj->getFlagGravityLabels() ?
+		prj->print_gravity180(constfont, XYname[0], XYname[1], nameI18, 1, -constfont->getStrLen(nameI18)/2) :
+		constfont->print(XYname[0]-constfont->getStrLen(nameI18)/2, XYname[1], nameI18);
 }
 
 // Draw the art texture, optimized function to be called thru a constellation manager only
-void Constellation::draw_art_optim(Projector* prj, navigator* nav) const
+void Constellation::draw_art_optim(Projector* prj, Navigator* nav) const
 {
-	float intensity = art_fader.get_interstate(); 
+	float intensity = art_fader.getInterstate(); 
 	if (art_tex && intensity) 
 	{
 		glColor3f(intensity,intensity,intensity);
@@ -132,15 +136,15 @@ void Constellation::draw_art_optim(Projector* prj, navigator* nav) const
 		bool b0, b1, b2, b3, b4, b5, b6, b7, b8; 
 
 		// If one of the point is in the screen
-		b0 = prj->project_prec_earth_equ_check(art_vertex[0],v0) || (nav->get_prec_equ_vision().dot(art_vertex[0])>0.9);
-		b1 = prj->project_prec_earth_equ_check(art_vertex[1],v1) || (nav->get_prec_equ_vision().dot(art_vertex[1])>0.9);
-		b2 = prj->project_prec_earth_equ_check(art_vertex[2],v2) || (nav->get_prec_equ_vision().dot(art_vertex[2])>0.9);
-		b3 = prj->project_prec_earth_equ_check(art_vertex[3],v3) || (nav->get_prec_equ_vision().dot(art_vertex[3])>0.9);
-		b4 = prj->project_prec_earth_equ_check(art_vertex[4],v4) || (nav->get_prec_equ_vision().dot(art_vertex[4])>0.9);
-		b5 = prj->project_prec_earth_equ_check(art_vertex[5],v5) || (nav->get_prec_equ_vision().dot(art_vertex[5])>0.9);
-		b6 = prj->project_prec_earth_equ_check(art_vertex[6],v6) || (nav->get_prec_equ_vision().dot(art_vertex[6])>0.9);
-		b7 = prj->project_prec_earth_equ_check(art_vertex[7],v7) || (nav->get_prec_equ_vision().dot(art_vertex[7])>0.9);
-		b8 = prj->project_prec_earth_equ_check(art_vertex[8],v8) || (nav->get_prec_equ_vision().dot(art_vertex[8])>0.9);
+		b0 = prj->project_j2000_check(art_vertex[0],v0) || (nav->get_prec_equ_vision().dot(art_vertex[0])>0.9);
+		b1 = prj->project_j2000_check(art_vertex[1],v1) || (nav->get_prec_equ_vision().dot(art_vertex[1])>0.9);
+		b2 = prj->project_j2000_check(art_vertex[2],v2) || (nav->get_prec_equ_vision().dot(art_vertex[2])>0.9);
+		b3 = prj->project_j2000_check(art_vertex[3],v3) || (nav->get_prec_equ_vision().dot(art_vertex[3])>0.9);
+		b4 = prj->project_j2000_check(art_vertex[4],v4) || (nav->get_prec_equ_vision().dot(art_vertex[4])>0.9);
+		b5 = prj->project_j2000_check(art_vertex[5],v5) || (nav->get_prec_equ_vision().dot(art_vertex[5])>0.9);
+		b6 = prj->project_j2000_check(art_vertex[6],v6) || (nav->get_prec_equ_vision().dot(art_vertex[6])>0.9);
+		b7 = prj->project_j2000_check(art_vertex[7],v7) || (nav->get_prec_equ_vision().dot(art_vertex[7])>0.9);
+		b8 = prj->project_j2000_check(art_vertex[8],v8) || (nav->get_prec_equ_vision().dot(art_vertex[8])>0.9);
 			
 		if (b0 || b1 || b2 || b3 || b4 || b5 || b6 || b7 || b8)
 		{
@@ -187,7 +191,7 @@ void Constellation::draw_art_optim(Projector* prj, navigator* nav) const
 }
 
 // Draw the art texture
-void Constellation::draw_art(Projector* prj, navigator* nav) const
+void Constellation::draw_art(Projector* prj, Navigator* nav) const
 {
 	glBlendFunc(GL_ONE, GL_ONE);
 	glEnable(GL_TEXTURE_2D);
@@ -203,7 +207,7 @@ void Constellation::draw_art(Projector* prj, navigator* nav) const
 	glDisable(GL_CULL_FACE);
 }
 
-const Constellation* Constellation::is_star_in(const Hip_Star * s) const
+const Constellation* Constellation::is_star_in(const HipStar * s) const
 {
     for(unsigned int i=0;i<nb_segments*2;++i)
     {
@@ -217,4 +221,61 @@ void Constellation::update(int delta_time)
 	line_fader.update(delta_time);
 	name_fader.update(delta_time);
 	art_fader.update(delta_time);
+	boundary_fader.update(delta_time);
+}
+
+// Draw the Constellation lines
+void Constellation::draw_boundary_optim(Projector* prj) const
+{
+	if(!boundary_fader.getInterstate()) return;
+
+	glDisable(GL_TEXTURE_2D);
+	glEnable(GL_BLEND);	
+	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA); // Normal transparency mode
+
+	// TODO - Fix this so that works like constellation art fade with selections
+	if(singleSelected) 	
+		glColor4f(boundaryColor[0], boundaryColor[1], boundaryColor[2], 1);  
+	else
+		glColor4f(boundaryColor[0], boundaryColor[1], boundaryColor[2], boundary_fader.getInterstate());
+
+	unsigned int i, j, size;
+	Vec3d pt1, pt2;
+	vector<Vec3f> *points;
+
+	if (singleSelected) size = isolatedBoundarySegments.size();
+	else size = sharedBoundarySegments.size();
+	
+	for (i=0;i<size;i++)
+	{
+		if (singleSelected) points = isolatedBoundarySegments[i];
+		else points = sharedBoundarySegments[i];
+
+		for (j=0;j<points->size()-1;j++)
+		{
+			if(prj->project_j2000_line_check(points->at(j),pt1,points->at(j+1),pt2)) 
+			{
+				glBegin(GL_LINES);
+					glVertex2f(pt1[0],pt1[1]);
+					glVertex2f(pt2[0],pt2[1]);
+				glEnd();
+			}
+		}			
+	}
+}
+
+HipStar* Constellation::getBrightestStar(void) const
+{
+	float maxMag = 99.f;
+	HipStar * brightest = NULL;
+	for(unsigned int i=0;i<nb_segments;++i)
+    {
+		const float Mag = asterism[2*i]->get_mag();
+		if (Mag < maxMag)
+		{
+			brightest = asterism[2*i];
+			maxMag = Mag;
+		}
+	}
+	return brightest;
 }
