@@ -21,31 +21,31 @@
 
 #include <iostream>
 #include <fstream>
+#include <vector>
 
-#include "constellation.h"
 #include "constellation_mgr.h"
+#include "constellation.h"
+#include "hip_star_mgr.h"
+#include "hip_star.h"
 #include "stel_utility.h"
 
 // constructor which loads all data from appropriate files
-Constellation_mgr::Constellation_mgr(Hip_Star_mgr *_hip_stars) : 
+ConstellationMgr::ConstellationMgr(HipStarMgr *_hip_stars) : 
 	asterFont(NULL),
 	hipStarMgr(_hip_stars),
-	selected(NULL)
+	selected(NULL),
+	flagNames(0),
+	flagLines(0),
+	flagArt(0),
+	flagBoundaries(0)
 {
 	assert(hipStarMgr);
-	isolateSelected = false; // Tony - flag for isolating the constellations 
+	isolateSelected = false;
 }
 
-void Constellation_mgr::set_font(const string& _font_filename)
+ConstellationMgr::~ConstellationMgr()
 {
-	if (asterFont) delete asterFont;
-	asterFont = new s_font(12., "spacefont", _font_filename);
-	assert(asterFont);
-}
-
-Constellation_mgr::~Constellation_mgr()
-{
-	vector < Constellation * >::iterator iter;
+	vector<Constellation *>::iterator iter;
 	for (iter = asterisms.begin(); iter != asterisms.end(); iter++)
 	{
 		delete(*iter);
@@ -53,11 +53,37 @@ Constellation_mgr::~Constellation_mgr()
 
 	if (asterFont) delete asterFont;
 	asterFont = NULL;
+
+	vector<vector<Vec3f> *>::iterator iter1;
+	for (iter1 = allBoundarySegments.begin(); iter1 != allBoundarySegments.end(); ++iter1)
+	{
+		delete (*iter1);
+	}
+	allBoundarySegments.clear();
+}
+
+void ConstellationMgr::setFlagGravityLabel(bool g) {Constellation::gravityLabel = g;}
+
+void ConstellationMgr::setLineColor(const Vec3f& c) {Constellation::lineColor = c;}
+Vec3f ConstellationMgr::getLineColor() const {return Constellation::lineColor;}
+
+void ConstellationMgr::setBoundaryColor(const Vec3f& c) {Constellation::boundaryColor = c;}
+Vec3f ConstellationMgr::getBoundaryColor() const {return Constellation::boundaryColor;}
+
+void ConstellationMgr::setLabelColor(const Vec3f& c) {Constellation::labelColor = c;}
+Vec3f ConstellationMgr::getLabelColor() const {return Constellation::labelColor;}
+
+void ConstellationMgr::setFont(float font_size, const string& ttfFileName)
+{
+	if (asterFont) delete asterFont;
+	asterFont = new s_font(font_size, ttfFileName);
+	assert(asterFont);
 }
 
 // Load line and art data from files
-void Constellation_mgr::load_lines_and_art(const string & fileName, const string & artfileName, LoadingBar& lb)
+void ConstellationMgr::loadLinesAndArt(const string &fileName, const string &artfileName, const string &boundaryfileName, LoadingBar& lb)
 {
+	
 	std::ifstream inf(fileName.c_str());
 
 	if (!inf.is_open())
@@ -81,23 +107,31 @@ void Constellation_mgr::load_lines_and_art(const string & fileName, const string
 	while(!std::getline(inf, record).eof())
 	{
 		line++;
+		if (record.size()!=0 && record[0]=='#')
+			continue;
 		cons = new Constellation;
-		assert(cons);
 		if(cons->read(record, hipStarMgr))
 		{
 			asterisms.push_back(cons);
 		} else
 		{ 
-			printf(_("ERROR on line %d of %s\n"), line, fileName.c_str());
+			cerr << "ERROR on line " << line << "of " << fileName.c_str() << endl;
 			delete cons;
 		}
 	}
 	inf.close();
 
+	// Set current states
+	setFlagArt(flagArt);
+	setFlagLines(flagLines);
+	setFlagNames(flagNames);	
+	setFlagBoundaries(flagBoundaries);	
+
+
 	FILE *fic = fopen(artfileName.c_str(), "r");
 	if (!fic)
 	{
-		printf("Can't open %s\n", artfileName.c_str());
+		cerr << "Can't open " << artfileName.c_str() << endl;
 		return; // no art, but still loaded constellation data
 	}
 
@@ -113,6 +147,7 @@ void Constellation_mgr::load_lines_and_art(const string & fileName, const string
 	char texfile[255];
 	unsigned int x1, y1, x2, y2, x3, y3, hp1, hp2, hp3;
 	int texSize;
+	
 	char tmpstr[2000];
 	int total = 0;
 
@@ -132,30 +167,28 @@ void Constellation_mgr::load_lines_and_art(const string & fileName, const string
 				fclose(fic);
 				return;		// no art is OK
 			}
-			printf("ERROR while loading art for constellation %s\n", shortname);
+			cerr << "Error while loading art for constellation " <<  shortname << endl;;
 			assert(0);
 		}
 
 		// Draw loading bar
-		//Tony - added "+1" to ensure art finsihes at last entry
-		sprintf(tmpstr, _("Loading Constellation Art: %d/%d"), current+1, total);
-		lb.SetMessage(tmpstr);
-		lb.Draw((float)current/total);
+		lb.SetMessage(_("Loading Constellation Art: ") + StelUtility::intToWstring(current+1) + L"/" + StelUtility::intToWstring(total));
+		lb.Draw((float)(current+1)/total);
 		
 		cons = NULL;
-		cons = find_from_short_name(shortname);
+		cons = findFromAbbreviation(shortname);
 		if (!cons)
 		{
-			printf("ERROR : Can't find constellation called : %s\n", shortname);
+			cerr << "ERROR : Can't find constellation called : " << shortname << endl;
 		}
 		else
 		{
 			cons->art_tex = new s_texture(texfile);
 			texSize = cons->art_tex->getSize();
 
-			Vec3f s1 = hipStarMgr->search(hp1)->get_prec_earth_equ_pos();
-			Vec3f s2 = hipStarMgr->search(hp2)->get_prec_earth_equ_pos();
-			Vec3f s3 = hipStarMgr->search(hp3)->get_prec_earth_equ_pos();
+			Vec3f s1 = hipStarMgr->searchHP(hp1)->getObsJ2000Pos();
+			Vec3f s2 = hipStarMgr->searchHP(hp2)->getObsJ2000Pos();
+			Vec3f s3 = hipStarMgr->searchHP(hp3)->getObsJ2000Pos();
 
 			// To transform from texture coordinate to 2d coordinate we need to find X with XA = B
 			// A formed of 4 points in texture coordinate, B formed with 4 points in 3d coordinate
@@ -180,22 +213,23 @@ void Constellation_mgr::load_lines_and_art(const string & fileName, const string
 		}
 	}
 	fclose(fic);
+	
+	loadBoundaries(boundaryfileName);
+	
 }
 
-
-void Constellation_mgr::draw(Projector * prj, navigator * nav) const
+void ConstellationMgr::draw(Projector * prj, Navigator * nav) const
 {
 	prj->set_orthographic_projection();
-	
 	draw_lines(prj);
 	draw_names(prj);
 	draw_art(prj, nav);
-	
+	drawBoundaries(prj);
 	prj->reset_perspective_projection();
 }
 
 // Draw constellations art textures
-void Constellation_mgr::draw_art(Projector * prj, navigator * nav) const
+void ConstellationMgr::draw_art(Projector * prj, Navigator * nav) const
 {
 	glBlendFunc(GL_ONE, GL_ONE);
 	glEnable(GL_TEXTURE_2D);
@@ -212,33 +246,38 @@ void Constellation_mgr::draw_art(Projector * prj, navigator * nav) const
 }
 
 // Draw constellations lines
-void Constellation_mgr::draw_lines(Projector * prj) const
+void ConstellationMgr::draw_lines(Projector * prj) const
 {
 	glDisable(GL_TEXTURE_2D);
-	glEnable(GL_BLEND);
+    glDisable(GL_BLEND);
+
 	vector < Constellation * >::const_iterator iter;
 	for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
 	{
-		(*iter)->draw_optim(prj, lines_color);
+		(*iter)->draw_optim(prj);
 	}
 }
 
 // Draw the names of all the constellations
-void Constellation_mgr::draw_names(Projector * prj) const
+void ConstellationMgr::draw_names(Projector * prj) const
 {
 	glEnable(GL_BLEND);
 	glEnable(GL_TEXTURE_2D);
-
+	
+	glBlendFunc(GL_ONE, GL_ONE);
+	// if (draw_mode == DM_NORMAL) glBlendFunc(GL_ONE, GL_ONE);
+	// else glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA); // charting
+	
 	vector < Constellation * >::const_iterator iter;
 	for (iter = asterisms.begin(); iter != asterisms.end(); iter++)
 	{
 		// Check if in the field of view
-		if (prj->project_prec_earth_equ_check((*iter)->XYZname, (*iter)->XYname))
-			(*iter)->draw_name(asterFont, prj, names_color);
+		if (prj->project_j2000_check((*iter)->XYZname, (*iter)->XYname))
+			(*iter)->draw_name(asterFont, prj);
 	}
 }
 
-Constellation *Constellation_mgr::is_star_in(const Hip_Star * s) const
+Constellation *ConstellationMgr::is_star_in(const HipStar * s) const
 {
 	vector < Constellation * >::const_iterator iter;
 	for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
@@ -250,113 +289,86 @@ Constellation *Constellation_mgr::is_star_in(const Hip_Star * s) const
 	return NULL;
 }
 
-Constellation *Constellation_mgr::find_from_short_name(const string & shortname) const
+Constellation *ConstellationMgr::findFromAbbreviation(const string & abbreviation) const
 {
 	// search in uppercase only
-	string tname = shortname;
+	string tname = abbreviation;
 	transform(tname.begin(), tname.end(), tname.begin(),::toupper);
 	
 	vector < Constellation * >::const_iterator iter;
 	for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
 	{
 		// Check if the star is in one of the constellation
-		if (string((*iter)->short_name) == tname)
+		if (string((*iter)->abbreviation) == tname)
 			return (*iter);
 	}
 	return NULL;
 }
 
 
-// Read constellation names from the given file
-void Constellation_mgr::load_names(const string& names_file)
+/** 
+ * @brief Read constellation names from the given file
+ * @param namesFile Name of the file containing the constellation names in english
+ */
+void ConstellationMgr::loadNames(const string& namesFile)
 {
-	vector < Constellation * >::const_iterator iter;
-	char short_name[4];
-	char cname[200];
-	Constellation *aster;
-	
 	// Constellation not loaded yet
 	if (asterisms.empty()) return;
 	
 	// clear previous names
+	vector < Constellation * >::const_iterator iter;
 	for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
 	{
-		(*iter)->set_name("");
+		(*iter)->englishName.clear();
 	}
 
 	// read in translated common names from file
-	FILE *cnFile;
-	cnFile = NULL;
-
-	cnFile = fopen(names_file.c_str(), "r");
-	if (!cnFile)
+	ifstream commonNameFile(namesFile.c_str());
+	if (!commonNameFile.is_open())
 	{
-		printf("WARNING %s NOT FOUND\n", names_file.c_str());
+		cerr << "Can't open file" << namesFile << endl;
 		return;
 	}
-
+	
 	// find matching constellation and update name
-	while (!feof(cnFile))
+	string record;
+	string tmpShortName;
+	Constellation *aster;
+	while (!std::getline(commonNameFile, record).eof())
 	{
-		fscanf(cnFile, "%s\t%s\n", short_name, cname);
-		aster = find_from_short_name(string(short_name));
-		if (aster != NULL)
-		{
 
-			int i=0;
-			while(cname[i] != 0 && i<199) {
-				if(cname[i]=='_') cname[i]=' ';
-				i++;
-			}
-			aster->set_name(cname);
+		if( record != "") {
+			istringstream in(record); 
+			in >> tmpShortName;
+
+			//	cout << "working on short name " << tmpShortName << endl;
+
+			aster = findFromAbbreviation(tmpShortName);
+			if (aster != NULL)
+				{
+					// Read the names in english
+					aster->englishName = record.substr(tmpShortName.length()+1,record.length()).c_str();
+				}
 		}
 	}
-	fclose(cnFile);
+	commonNameFile.close();
+
 }
 
-// Tony to get the names for the autocomplete
-vector <string> Constellation_mgr::getNames(void) 
+//! @brief Update i18 names from english names according to current locale
+//! The translation is done using gettext with translated strings defined in translations.h
+void ConstellationMgr::translateNames(Translator& trans)
 {
-     vector<string> names;
-  	 vector < Constellation * >::const_iterator iter;
-     string name;
-
+	vector < Constellation * >::const_iterator iter;
 	for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
 	{
-		name = (*iter)->getName();
-		transform(name.begin(), name.end(), name.begin(), ::tolower);
-		transform(name.begin(), name.begin()+1, name.begin(), ::toupper);
-        names.push_back(name);
-     }
-     return names;
-}
-
-// Tony to get the names for the autocomplete
-vector<string> Constellation_mgr::getShortNames(void)
-{
-    vector<string> names;
-	vector < Constellation * >::const_iterator iter;
-
-	for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
-        names.push_back((*iter)->getShortName());
-    return names;
-}
-
-string Constellation_mgr::get_short_name_by_name(string _name) {
-
-	vector < Constellation * >::const_iterator iter;
-
-	for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
-	{
-		if( str_compare_case_insensitive(_name, (*iter)->getName()) == 0) return (*iter)->getShortName();
+		(*iter)->nameI18 = trans.translate((*iter)->englishName.c_str());
+		//cout << (*iter)->englishName.c_str() << " -> " << StelUtility::wstringToString((*iter)->nameI18) << endl;
 	}
-	return "";
-
 }
 
-
 // update faders
-void Constellation_mgr::update(int delta_time)
+void ConstellationMgr::update(int delta_time)
 {
 	vector < Constellation * >::const_iterator iter;
 	for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
@@ -366,64 +378,84 @@ void Constellation_mgr::update(int delta_time)
 }
 
 
-void Constellation_mgr::set_art_intensity(float _max)
+void ConstellationMgr::setArtIntensity(float _max)
 {
+	artMaxIntensity = _max;
 	vector < Constellation * >::const_iterator iter;
 	for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
 		(*iter)->art_fader.set_max_value(_max);
 }
 
-void Constellation_mgr::set_art_fade_duration(float duration)
+void ConstellationMgr::setArtFadeDuration(float duration)
 {
+	artFadeDuration = duration;
 	vector < Constellation * >::const_iterator iter;
 	for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
 		(*iter)->art_fader.set_duration((int) (duration * 1000.f));
 }
 
-void Constellation_mgr::set_flag_lines(bool b)
+void ConstellationMgr::setFlagLines(bool b)
 {
+	flagLines = b;
 	if (selected && isolateSelected)
 	{
-		selected->set_flag_lines(b);
+		selected->setFlagLines(b);
 	}
 	else
 	{
 		vector < Constellation * >::const_iterator iter;
 		for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
-			(*iter)->set_flag_lines(b);
+			(*iter)->setFlagLines(b);
 	}
 }
 
-void Constellation_mgr::set_flag_art(bool b)
+void ConstellationMgr::setFlagBoundaries(bool b)
 {
+	flagBoundaries = b;
 	if (selected && isolateSelected)
 	{
-		selected->set_flag_art(b);
+		selected->setFlagBoundaries(b);
 	}
 	else
 	{
 		vector < Constellation * >::const_iterator iter;
 		for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
-			(*iter)->set_flag_art(b);
+			(*iter)->setFlagBoundaries(b);
 	}
 }
 
-
-void Constellation_mgr::set_flag_names(bool b)
+void ConstellationMgr::setFlagArt(bool b)
 {
+	flagArt = b;
 	if (selected && isolateSelected)
 	{
-		selected->set_flag_name(b);
+		selected->setFlagArt(b);
 	}
 	else
 	{
 		vector < Constellation * >::const_iterator iter;
 		for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
-			(*iter)->set_flag_name(b);
+			(*iter)->setFlagArt(b);
 	}
 }
 
-void Constellation_mgr::set_selected_const(Constellation * c)
+
+void ConstellationMgr::setFlagNames(bool b)
+{
+	flagNames = b;
+	if (selected && isolateSelected)
+	{
+		selected->setFlagName(b);
+	}
+	else
+	{
+		vector < Constellation * >::const_iterator iter;
+		for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
+			(*iter)->setFlagName(b);
+	}
+}
+
+void ConstellationMgr::setSelectedConst(Constellation * c)
 {
 	// update states for other constellations to fade them out
 	if (c != NULL)
@@ -432,12 +464,12 @@ void Constellation_mgr::set_selected_const(Constellation * c)
 		// Propagate old parameters new newly selected constellation
 		if (selected) cc=selected;
 		else cc=*(asterisms.begin());
-		c->set_flag_lines(cc->get_flag_lines());
-		c->set_flag_name(cc->get_flag_name());
-		c->set_flag_art(cc->get_flag_art());
+		c->setFlagLines(cc->getFlagLines());
+		c->setFlagName(cc->getFlagName());
+		c->setFlagArt(cc->getFlagArt());
+		c->setFlagBoundaries(cc->getFlagBoundaries());
 		selected = c;
 				
-		// Tony - isolateSelected flag for isolating the constellations 
 		if (isolateSelected)
 		{
 		    vector < Constellation * >::const_iterator iter;
@@ -445,21 +477,25 @@ void Constellation_mgr::set_selected_const(Constellation * c)
 		    {
                 if ((*iter) != selected)
 	    	    {
-	    	        (*iter)->set_flag_lines(false);
-		            (*iter)->set_flag_name(false);
-		            (*iter)->set_flag_art(false);
+	    	        (*iter)->setFlagLines(false);
+		            (*iter)->setFlagName(false);
+		            (*iter)->setFlagArt(false);
+		            (*iter)->setFlagBoundaries(false);
 		        }
              }
+             Constellation::singleSelected = true;
         }
 		else
 		{
 			vector < Constellation * >::const_iterator iter;
 			for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
 			{
-					(*iter)->set_flag_lines(c->get_flag_lines());
-					(*iter)->set_flag_name(c->get_flag_name());
-					(*iter)->set_flag_art(c->get_flag_art());
+					(*iter)->setFlagLines(c->getFlagLines());
+					(*iter)->setFlagName(c->getFlagName());
+					(*iter)->setFlagArt(c->getFlagArt());
+		            (*iter)->setFlagBoundaries(c->getFlagBoundaries());
 			}
+             Constellation::singleSelected = false;
 		}
 	}
 	else
@@ -470,11 +506,158 @@ void Constellation_mgr::set_selected_const(Constellation * c)
 		{
 			if ((*iter) != selected)
 			{
-				(*iter)->set_flag_lines(selected->get_flag_lines());
-				(*iter)->set_flag_name(selected->get_flag_name());
-				(*iter)->set_flag_art(selected->get_flag_art());
+				(*iter)->setFlagLines(selected->getFlagLines());
+				(*iter)->setFlagName(selected->getFlagName());
+				(*iter)->setFlagArt(selected->getFlagArt());
+				(*iter)->setFlagBoundaries(selected->getFlagBoundaries());
 			}
 		}
 		selected = NULL;
 	}
 }
+
+// Load from file 
+bool ConstellationMgr::loadBoundaries(const string& boundaryFile)
+{
+	Constellation *cons = NULL;
+	unsigned int i, j;
+	
+	vector<vector<Vec3f> *>::iterator iter;
+	for (iter = allBoundarySegments.begin(); iter != allBoundarySegments.end(); ++iter)
+	{
+		delete (*iter);
+	}
+	allBoundarySegments.clear();
+
+    cout << "Loading Constellation boundary data...";
+	// Modified boundary file by Torsten Bronger with permission
+	// http://pp3.sourceforge.net
+	
+    ifstream dataFile;
+	dataFile.open(boundaryFile.c_str());
+    if (!dataFile.is_open())
+    {
+        cerr << "Boundary file " << boundaryFile << " not found" << endl;
+        return false;
+    }
+
+	float DE, RA;
+	float oDE, oRA;
+	Vec3f XYZ;
+	unsigned num, numc;
+	vector<Vec3f> *points = NULL;
+	string consname;
+	i = 0;
+	while (!dataFile.eof())	
+	{
+		points = new vector<Vec3f>;
+
+		num = 0;
+		dataFile >> num;
+		if(num == 0) continue;  // empty line
+
+		for (j=0;j<num;j++)
+		{
+			dataFile >> RA >> DE;
+
+			oRA =RA;
+			oDE= DE;
+
+			RA*=M_PI/12.;     // Convert from hours to rad
+			DE*=M_PI/180.;    // Convert from deg to rad
+
+			// Calc the Cartesian coord with RA and DE
+	    	sphe_to_rect(RA,DE,XYZ);
+			points->push_back(XYZ);
+		}
+		
+		// this list is for the de-allocation
+		allBoundarySegments.push_back(points);
+
+		dataFile >> numc;  
+		// there are 2 constellations per boundary
+		
+		for (j=0;j<numc;j++)
+		{
+			dataFile >> consname;
+			// not used?
+			if (consname == "SER1" || consname == "SER2") consname = "SER";
+			
+			cons = findFromAbbreviation(consname);
+				if (!cons) cout << "ERROR : Can't find constellation called : " << consname << endl;
+			else cons->isolatedBoundarySegments.push_back(points);
+		}
+
+		if (cons) cons->sharedBoundarySegments.push_back(points);
+		i++;
+
+	}
+    dataFile.close();
+	cout << "(" << i << " segments loaded)" << endl;
+    delete points;
+    
+    return true;
+}
+
+// Draw constellations lines
+void ConstellationMgr::drawBoundaries(Projector * prj) const
+{
+	glDisable(GL_TEXTURE_2D);
+    glDisable(GL_BLEND);
+
+	glLineStipple(2, 0x3333);
+	glEnable(GL_LINE_STIPPLE);
+
+	vector < Constellation * >::const_iterator iter;
+	for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
+	{
+		(*iter)->draw_boundary_optim(prj);
+	}
+	glDisable(GL_LINE_STIPPLE);
+}
+
+unsigned int ConstellationMgr::getFirstSelectedHP(void) {
+  if (selected) return selected->asterism[0]->get_hp_number();
+  return 0;
+}
+
+//! Return the matching constellation object's pointer if exists or NULL
+//! @param nameI18n The case sensistive constellation name
+Constellation* ConstellationMgr::searchByNameI18n(const wstring& nameI18n) const
+{
+	wstring objw = nameI18n;
+	transform(objw.begin(), objw.end(), objw.begin(), ::toupper);
+	
+	vector <Constellation*>::const_iterator iter;
+	for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
+	{
+		wstring objwcap = (*iter)->nameI18;
+		transform(objwcap.begin(), objwcap.end(), objwcap.begin(), ::toupper);
+		if (objwcap==objw) return *iter;
+	}
+	return NULL;
+}
+
+//! Find and return the list of at most maxNbItem objects auto-completing the passed object I18n name
+vector<wstring> ConstellationMgr::listMatchingObjectsI18n(const wstring& objPrefix, unsigned int maxNbItem) const
+{
+	vector<wstring> result;
+	if (maxNbItem==0) return result;
+		
+	wstring objw = objPrefix;
+	transform(objw.begin(), objw.end(), objw.begin(), ::toupper);
+	
+	vector < Constellation * >::const_iterator iter;
+	for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
+	{
+		wstring constw = (*iter)->getNameI18().substr(0, objw.size());
+		transform(constw.begin(), constw.end(), constw.begin(), ::toupper);
+		if (constw==objw)
+		{
+			result.push_back((*iter)->getNameI18());
+			if (result.size()==maxNbItem)
+				return result;
+		}
+	}
+	return result;
+}
