@@ -82,15 +82,15 @@ SkyGrid::~SkyGrid()
 
 }
 
-void SkyGrid::set_font(const string& font_filename, const string& font_texture)
+void SkyGrid::set_font(float font_size, const string& font_name)
 {
-	font = new s_font(12, font_texture, font_filename);
+	font = new s_font(font_size, font_name);
 	assert(font);
 }
 
 void SkyGrid::draw(const Projector* prj) const
 {
-	if (!fader.get_interstate()) return;
+	if (!fader.getInterstate()) return;
 
 	glDisable(GL_TEXTURE_2D);
 	glEnable(GL_BLEND);	
@@ -109,83 +109,91 @@ void SkyGrid::draw(const Projector* prj) const
 			if ((prj->*proj_func)(alt_points[nm][0], pt1) &&
 				(prj->*proj_func)(alt_points[nm][1], pt2) )
 			{
+              const double dx = pt1[0]-pt2[0];
+              const double dy = pt1[1]-pt2[1];
+              const double dq = dx*dx+dy*dy;
+              if (dq < 1024*1024) {
 				glColor4f(color[0],color[1],color[2],0.f);
 
 				glBegin (GL_LINES);
 					glVertex2f(pt1[0],pt1[1]);
-					glColor4f(color[0],color[1],color[2],fader.get_interstate());
+					glColor4f(color[0],color[1],color[2],fader.getInterstate());
 					glVertex2f(pt2[0],pt2[1]);
         		glEnd();
+              }
 			}
 
-			glColor4f(color[0],color[1],color[2],fader.get_interstate());
+			glColor4f(color[0],color[1],color[2],fader.getInterstate());
 
 			for (unsigned int i=1;i<nb_alt_segment-1;++i)
 			{
 				if ((prj->*proj_func)(alt_points[nm][i], pt1) &&
 					(prj->*proj_func)(alt_points[nm][i+1], pt2) )
 				{
-				  glBegin(GL_LINES);
-				  glVertex2f(pt1[0],pt1[1]);
-				  glVertex2f(pt2[0],pt2[1]);
-				  glEnd();
-				  
-				  static char str[255];	// TODO use c++ string 
-				  
-				  glEnable(GL_TEXTURE_2D);
+                  const double dx = pt1[0]-pt2[0];
+                  const double dy = pt1[1]-pt2[1];
+                  const double dq = dx*dx+dy*dy;
+                  if (dq < 1024*1024) {
+				    glBegin(GL_LINES);
+				    glVertex2f(pt1[0],pt1[1]);
+				    glVertex2f(pt2[0],pt2[1]);
+				    glEnd();
 
-				  double angle;
-				  double d;
+				    static char str[255];	// TODO use c++ string 
 
-				  // TODO: allow for other numbers of meridians and parallels without
-				  // screwing up labels?
-				  if( gtype == EQUATORIAL && i == 8 ) {
+				    glEnable(GL_TEXTURE_2D);
+
+				    double angle;
+
+				    // TODO: allow for other numbers of meridians and parallels without
+				    // screwing up labels?
+				    if( gtype == EQUATORIAL && i == 8 ) {
+
+				      // draw labels along equator for RA
+				      const double d = sqrt(dq);
+
+				      angle = acos((pt1[1]-pt2[1])/d);
+				      if( pt1[0] < pt2[0] ) {
+				        angle *= -1;
+				      }
+
+				      sprintf( str, "%dh", nm);
+
+				      prj->set_orthographic_projection();
+
+				      glTranslatef(pt2[0],pt2[1],0);
+				      glRotatef(90+angle*180./M_PI,0,0,-1);
+				      font->print(2,-2,str);
+
+				      prj->reset_perspective_projection();
+
+
+				    } else if (nm % 8 == 0 && i != 16) {
+
+				      const double d = sqrt(dq);
+
+				      angle = acos((pt1[1]-pt2[1])/d);
+				      if( pt1[0] < pt2[0] ) {
+				        angle *= -1;
+				      }
+
+				      sprintf( str, "%d", (i-8)*10);
+
+				      if( gtype == ALTAZIMUTAL || 
+					  (gtype == EQUATORIAL && i > 8)) {
+				        angle += M_PI;
+				      }
+
+				      prj->set_orthographic_projection();
+
+				      glTranslatef(pt2[0],pt2[1],0);
+				      glRotatef(angle*180./M_PI,0,0,-1);
+				      font->print(2,-2,str);
+				      prj->reset_perspective_projection();
 
-				    // draw labels along equator for RA
-				    d = sqrt( (pt1[0]-pt2[0])*(pt1[0]-pt2[0]) + (pt1[1]-pt2[1])*(pt1[1]-pt2[1]) );
-				  
-				    angle = acos((pt1[1]-pt2[1])/d);
-				    if( pt1[0] < pt2[0] ) {
-				      angle *= -1;
 				    }
-
-				    sprintf( str, "%dh", nm);
-
-				    prj->set_orthographic_projection();
-				  
-				    glTranslatef(pt2[0],pt2[1],0);
-				    glRotatef(90+angle*180./M_PI,0,0,-1);
-				    font->print(2,-2,str);
-
-				    prj->reset_perspective_projection();
-
-
-				  } else if (nm % 8 == 0 && i != 16) {
-					  
-				    d = sqrt( (pt1[0]-pt2[0])*(pt1[0]-pt2[0]) + (pt1[1]-pt2[1])*(pt1[1]-pt2[1]) );
-				  
-				    angle = acos((pt1[1]-pt2[1])/d);
-				    if( pt1[0] < pt2[0] ) {
-				      angle *= -1;
-				    }
-
-				    sprintf( str, "%d", (i-8)*10);
-					    
-				    if( gtype == ALTAZIMUTAL || 
-					(gtype == EQUATORIAL && i > 8)) {
-				      angle += M_PI;
-				    }
-
-				    prj->set_orthographic_projection();
-
-				    glTranslatef(pt2[0],pt2[1],0);
-				    glRotatef(angle*180./M_PI,0,0,-1);
-				    font->print(2,-2,str);
-				    prj->reset_perspective_projection();
-
+				    glDisable(GL_TEXTURE_2D);
 				  }
-				  glDisable(GL_TEXTURE_2D);
-				  
 				}
 
 
@@ -194,34 +202,44 @@ void SkyGrid::draw(const Projector* prj) const
 			if ((prj->*proj_func)(alt_points[nm][nb_alt_segment-1], pt1) &&
 				(prj->*proj_func)(alt_points[nm][nb_alt_segment], pt2) )
 			{
-				glColor4f(color[0],color[1],color[2],fader.get_interstate());
+              const double dx = pt1[0]-pt2[0];
+              const double dy = pt1[1]-pt2[1];
+              const double dq = dx*dx+dy*dy;
+              if (dq < 1024*1024) {
+				glColor4f(color[0],color[1],color[2],fader.getInterstate());
 				glBegin (GL_LINES);
 					glVertex2f(pt1[0],pt1[1]);
 					glColor4f(color[0],color[1],color[2],0.f);
 					glVertex2f(pt2[0],pt2[1]);
         		glEnd();
+              }
 			}
 
 		}
 		else
 		{
-			glColor4f(color[0],color[1],color[2],fader.get_interstate());
+			glColor4f(color[0],color[1],color[2],fader.getInterstate());
 			for (unsigned int i=0;i<nb_alt_segment;++i)
 			{
 				if ((prj->*proj_func)(alt_points[nm][i], pt1) &&
 					(prj->*proj_func)(alt_points[nm][i+1], pt2) )
 				{
+                  const double dx = pt1[0]-pt2[0];
+                  const double dy = pt1[1]-pt2[1];
+                  const double dq = dx*dx+dy*dy;
+                  if (dq < 1024*1024) {
 					glBegin (GL_LINES);
 						glVertex2f(pt1[0],pt1[1]);
 						glVertex2f(pt2[0],pt2[1]);
         			glEnd();
+                  }
 				}
 			}
 		}
 	}
 
 	// Draw parallels
-	glColor4f(color[0],color[1],color[2],fader.get_interstate());
+	glColor4f(color[0],color[1],color[2],fader.getInterstate());
 	for (unsigned int np=0;np<nb_parallel;++np)
 	{
 		for (unsigned int i=0;i<nb_azi_segment;++i)
@@ -229,10 +247,15 @@ void SkyGrid::draw(const Projector* prj) const
 			if ((prj->*proj_func)(azi_points[np][i], pt1) &&
 				(prj->*proj_func)(azi_points[np][i+1], pt2) )
 			{
+              const double dx = pt1[0]-pt2[0];
+              const double dy = pt1[1]-pt2[1];
+              const double dq = dx*dx+dy*dy;
+              if (dq < 1024*1024) {
 				glBegin (GL_LINES);
 					glVertex2f(pt1[0],pt1[1]);
 					glVertex2f(pt2[0],pt2[1]);
         		glEnd();
+              }
 			}
 		}
 	}
@@ -241,21 +264,30 @@ void SkyGrid::draw(const Projector* prj) const
 }
 
 
-SkyLine::SkyLine(SKY_LINE_TYPE line_type, double _radius, unsigned int _nb_segment) :
-	radius(_radius), nb_segment(_nb_segment), color(0.f, 0.f, 1.f)
+SkyLine::SkyLine(SKY_LINE_TYPE _line_type, double _radius, unsigned int _nb_segment) :
+	radius(_radius), nb_segment(_nb_segment), color(0.f, 0.f, 1.f), font(NULL)
 {
 	float inclinaison = 0.f;
+	line_type = _line_type;
+
 	switch (line_type)
-	{
+		{
 		case LOCAL : proj_func = &Projector::project_local; break;
-		case ECLIPTIC : proj_func = &Projector::project_earth_equ;
-						inclinaison = 23.45f; break;
+		case MERIDIAN : proj_func = &Projector::project_local; 
+			inclinaison = 90; break;
+		case ECLIPTIC : proj_func = &Projector::project_j2000;
+			inclinaison = 23.4392803055555555556; break;
 		case EQUATOR : proj_func = &Projector::project_earth_equ; break;
 		default : proj_func = &Projector::project_earth_equ;
 	}
 
 	Mat4f r = Mat4f::xrotation(inclinaison*M_PI/180.f);
 
+	// Ecliptic month labels need to be redone
+	// correct for month labels
+	// TODO: can make this more accurate
+	//	if(line_type == ECLIPTIC ) r = r * Mat4f::zrotation(-77.9*M_PI/180.);
+
 	// Points to draw along the circle
 	points = new Vec3f[nb_segment+1];
 	for (unsigned int i=0;i<nb_segment+1;++i)
@@ -270,16 +302,25 @@ SkyLine::~SkyLine()
 {
 	delete [] points;
 	points = NULL;
+	if (font) delete font;
+	font = NULL;
+}
+
+void SkyLine::set_font(float font_size, const string& font_name)
+{
+	if (font) delete font;
+	font = new s_font(font_size, font_name);
+	assert(font);
 }
 
 void SkyLine::draw(const Projector* prj) const
 {
-	if (!fader.get_interstate()) return;
+	if (!fader.getInterstate()) return;
 
 	Vec3d pt1;
 	Vec3d pt2;
 
-	glColor4f(color[0], color[1], color[2], fader.get_interstate());
+	glColor4f(color[0], color[1], color[2], fader.getInterstate());
 	glDisable(GL_TEXTURE_2D);
 	glEnable(GL_BLEND);	
 	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA); // Normal transparency mode
@@ -291,10 +332,119 @@ void SkyLine::draw(const Projector* prj) const
 		if ((prj->*proj_func)(points[i], pt1) &&
 			(prj->*proj_func)(points[i+1], pt2) )
 		{
+          const double dx = pt1[0]-pt2[0];
+          const double dy = pt1[1]-pt2[1];
+          const double dq = dx*dx+dy*dy;
+          if (dq < 1024*1024) {
+
+			double angle;
+
+			// TODO: allow for other numbers of meridians and parallels without
+			// screwing up labels?
+
 			glBegin (GL_LINES);
 				glVertex2f(pt1[0],pt1[1]);
 				glVertex2f(pt2[0],pt2[1]);
        		glEnd();
+
+
+			if(line_type == MERIDIAN) {
+				const double d = sqrt(dq);
+				  
+				angle = acos((pt1[1]-pt2[1])/d);
+				if( pt1[0] < pt2[0] ) {
+					angle *= -1;
+				}
+
+				// draw text label
+				std::ostringstream oss;	
+				
+				if(i<=8) oss << (i+1)*10;
+				else if(i<=16) {
+					oss << (17-i)*10;
+					angle += M_PI;
+				}
+				else oss << "";
+				
+				glPushMatrix();
+				glTranslatef(pt2[0],pt2[1],0);
+				glRotatef(180+angle*180./M_PI,0,0,-1);
+				
+				glBegin (GL_LINES);
+				glVertex2f(-3,0);
+				glVertex2f(3,0);
+				glEnd();
+				glEnable(GL_TEXTURE_2D);
+
+				if(font) font->print(2,-2,oss.str());
+				glPopMatrix();
+				glDisable(GL_TEXTURE_2D);
+
+			}
+
+				  
+			if(line_type == EQUATOR && (i+1) % 2 == 0) {
+
+				const double d = sqrt(dq);
+				  
+				angle = acos((pt1[1]-pt2[1])/d);
+				if( pt1[0] < pt2[0] ) {
+					angle *= -1;
+				}
+
+				// draw text label
+				std::ostringstream oss;	
+
+				if((i+1)/2 == 24) oss << "0h";
+				else oss << (i+1)/2 << "h";
+
+				glPushMatrix();
+				glTranslatef(pt2[0],pt2[1],0);
+				glRotatef(180+angle*180./M_PI,0,0,-1);
+				
+				glBegin (GL_LINES);
+				glVertex2f(-3,0);
+				glVertex2f(3,0);
+				glEnd();
+				glEnable(GL_TEXTURE_2D);
+
+				if(font) font->print(2,-2,oss.str());
+				glPopMatrix();
+				glDisable(GL_TEXTURE_2D);
+
+			}
+
+			// Draw months on ecliptic
+			/*
+			if(line_type == ECLIPTIC && (i+3) % 4 == 0) {
+
+				const double d = sqrt(dq);
+				  
+				angle = acos((pt1[1]-pt2[1])/d);
+				if( pt1[0] < pt2[0] ) {
+					angle *= -1;
+				}
+
+				// draw text label
+				std::ostringstream oss;	
+
+				oss << (i+3)/4;
+
+				glPushMatrix();
+				glTranslatef(pt2[0],pt2[1],0);
+				glRotatef(-90+angle*180./M_PI,0,0,-1);
+				
+				glEnable(GL_TEXTURE_2D);
+
+				if(font) font->print(0,-2,oss.str());
+				glPopMatrix();
+				glDisable(GL_TEXTURE_2D);
+
+			}
+			*/
+
+		  }
+
 		}
 	}
 
@@ -306,10 +456,10 @@ Cardinals::Cardinals(float _radius) : radius(_radius), font(NULL), color(0.6,0.2
 {
 	// Default labels - if sky locale specified, loaded later
 	// Improvement for gettext translation
-	sNorth = _("N");
-	sSouth = _("S");
-	sEast = _("E");
-	sWest = _("W");
+	sNorth = L"N";
+	sSouth = L"S";
+	sEast = L"E";
+	sWest = L"W";
 }
 
 Cardinals::~Cardinals()
@@ -318,9 +468,14 @@ Cardinals::~Cardinals()
 	font = NULL;
 }
 
-void Cardinals::set_font(const string& font_filename, const string& font_texture, float font_size)
+/**
+ * Set the font for cardinal points
+ * @param font_size size in pixel
+ * @param font_name name of the font
+ */
+void Cardinals::set_font(float font_size, const string& font_name)
 {
-	font = new s_font(font_size, font_texture, font_filename);
+	font = new s_font(font_size, font_name);
 	assert(font);
 }
 
@@ -329,10 +484,10 @@ void Cardinals::set_font(const string& font_filename, const string& font_texture
 void Cardinals::draw(const Projector* prj, double latitude, bool gravityON) const
 {
 
-	if (!fader.get_interstate()) return;
+	if (!fader.getInterstate()) return;
 
 	// direction text
-	string d[4];
+	wstring d[4];
 	
 	d[0] = sNorth;
 	d[1] = sSouth;
@@ -343,7 +498,7 @@ void Cardinals::draw(const Projector* prj, double latitude, bool gravityON) cons
 	if(latitude ==  90.0 ) d[0] = d[1] = d[2] = d[3] = sSouth;
 	if(latitude == -90.0 ) d[0] = d[1] = d[2] = d[3] = sNorth;
 
-	glColor4f(color[0],color[1],color[2],fader.get_interstate());
+	glColor4f(color[0],color[1],color[2],fader.getInterstate());
 	glEnable(GL_BLEND);
 	glEnable(GL_TEXTURE_2D);
 	// Normal transparency mode
@@ -356,7 +511,7 @@ void Cardinals::draw(const Projector* prj, double latitude, bool gravityON) cons
 
 	float shift = font->getStrLen(sNorth)/2;
 
-	if (gravityON)
+	if (prj->getFlagGravityLabels())
 	{
 		// N for North
 		pos.set(-1.f, 0.f, 0.22f);
@@ -396,31 +551,13 @@ void Cardinals::draw(const Projector* prj, double latitude, bool gravityON) cons
 	prj->reset_perspective_projection();
 }
 
-// load cardinal labels from a file for i18n to sky language
-// (not using gettext because sky language not the same as ui language)
-
-int Cardinals::load_labels(string filename)
+// Translate cardinal labels with gettext to current sky language
+void Cardinals::translateLabels(Translator& trans)
 {
-    ifstream input_file;
-
-	input_file.open(filename.c_str());
-
-	if (! input_file.is_open())
-	{
-		printf("Error opening %s\n", filename.c_str());
-
-		// Default labels - if sky locale specified, loaded later
-		// Improvement for gettext translation
-		sNorth = _("N");
-		sSouth = _("S");
-		sEast = _("E");
-		sWest = _("W");
-
-		return 0;
-	}
-
-	input_file >> sNorth >> sEast >> sSouth >> sWest;
-	return 1;
+		sNorth = trans.translate("N");
+		sSouth = trans.translate("S");
+		sEast = trans.translate("E");
+		sWest = trans.translate("W");
 }
 
 // Class which manages the displaying of the Milky Way
@@ -435,10 +572,10 @@ MilkyWay::~MilkyWay()
 	tex = NULL;
 }
 
-void MilkyWay::set_texture(const string& tex_file)
+void MilkyWay::set_texture(const string& tex_file, bool blend)
 {
 	if (tex) delete tex;
-	tex = new s_texture(tex_file,TEX_LOAD_TYPE_PNG_SOLID_REPEAT);
+ 	tex = new s_texture(tex_file,!blend ? TEX_LOAD_TYPE_PNG_SOLID_REPEAT : TEX_LOAD_TYPE_PNG_BLEND3);
 
 	// big performance improvement to cache this
 	tex_avg_luminance = tex->get_average_luminance();
@@ -450,21 +587,21 @@ void MilkyWay::set_intensity(float _intensity)
 	intensity = _intensity;
 }
 
-void MilkyWay::draw(tone_reproductor * eye, const Projector* prj, const navigator* nav) const
+void MilkyWay::draw(ToneReproductor * eye, const Projector* prj, const Navigator* nav) const
 {
 	assert(tex);	// A texture must be loaded before calling this
 	// Scotopic color = 0.25, 0.25 in xyY mode. Global stars luminance ~= 0.001 cd/m^2
-	Vec3f c = Vec3f(0.25f, 0.25f, intensity*0.002f);
+	Vec3f c = Vec3f(0.25f*fader.getInterstate(), 0.25f*fader.getInterstate(),
+                    intensity*0.002f*fader.getInterstate()/tex_avg_luminance);
 	eye->xyY_to_RGB(c);
 	glColor3fv(c);
-	c[2]/=tex_avg_luminance;
 	glEnable(GL_CULL_FACE);
 	glEnable(GL_TEXTURE_2D);
 	glDisable(GL_BLEND);
 	glBindTexture(GL_TEXTURE_2D, tex->getID());
 
-	prj->sSphere(radius,20,20,
-		     nav->get_prec_earth_equ_to_eye_mat()*
+	prj->sSphere(radius,1.0,20,20,
+		     nav->get_j2000_to_eye_mat()*
 		     Mat4d::xrotation(M_PI/180*23)*
 		     Mat4d::yrotation(M_PI/180*120)*
 		     Mat4d::zrotation(M_PI/180*7), 1);
@@ -472,9 +609,28 @@ void MilkyWay::draw(tone_reproductor * eye, const Projector* prj, const navigato
 	glDisable(GL_CULL_FACE);
 }
 
+void MilkyWay::draw_chart(ToneReproductor * eye, const Projector* prj, const Navigator* nav) 
+{
+	assert(tex);	// A texture must be loaded before calling this
+
+	glColor3fv(color);
+	glEnable(GL_CULL_FACE);
+	glEnable(GL_TEXTURE_2D); 
+	glEnable(GL_BLEND);
+	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+	glBindTexture(GL_TEXTURE_2D, tex->getID());
+
+	prj->sSphere(radius,1.0,20,20,
+		     nav->get_j2000_to_eye_mat()*
+		     Mat4d::xrotation(M_PI/180*23)*
+		     Mat4d::yrotation(M_PI/180*120)*
+		     Mat4d::zrotation(M_PI/180*7), 1);
+
+	glDisable(GL_CULL_FACE);
+}
 
 // Draw a point... (used for tests)
-void DrawPoint(float X,float Y,float Z)
+void Draw::drawPoint(float X,float Y,float Z)
 {       
 	glColor3f(0.8, 1.0, 0.8);
 	glDisable(GL_TEXTURE_2D);
