@@ -28,8 +28,11 @@
 #endif
 
 #ifndef HAVE_POW10
-# define pow10(x) (float)pow(10.f,(x))
+# define pow10(x) pow(10,(x))
 #endif
+
+#ifndef WIN32
+
 #ifndef HAVE_ACOSF
 # define acosf(x) (float)(acos(x))
 #endif
@@ -64,4 +67,6 @@
 # define sqrtf(x) (float)(sqrt(x))
 #endif
 
+#endif /* CYGWIN */
+
 #endif /*_FMATH_H_*/
