@@ -1,6 +1,6 @@
 /*
  * Stellarium
- * Copyright (C) 2002 Fabien Chreau
+ * Copyright (C) 2002 Fabien Chereau
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,14 +28,16 @@ class Grid
 public:
     Grid();
     virtual ~Grid();
-    int GetNearest(Vec3f);
+    int GetNearest(Vec3f&);
 	void Draw(void);
-	int Intersect(Vec3f pos, float fieldAngle, int * &result);
+	int Intersect(Vec3f pos, float fieldAngle);
+	int * getResult(void) const {return result;}
 	int getNbPoints(void) const {return NbPoints;}
 private:
     float Angle;     // Radius of each zone (in radians)
     int NbPoints;    // Number of zones
     Vec3f * Points; // The zones positions
+	int * result;
 };
 
 #endif // _GRID_H_
