@@ -22,54 +22,93 @@
 
 Landscape::Landscape(float _radius) : radius(_radius), sky_brightness(1.)
 {
-  valid_landscape = 0;
+	valid_landscape = 0;
 }
 
 Landscape::~Landscape()
-{
-}
+{}
 
 Landscape* Landscape::create_from_file(const string& landscape_file, const string& section_name)
 {
-	init_parser pd;	// The landscape data ini file parser
+	InitParser pd;	// The landscape data ini file parser
 	pd.load(landscape_file);
 	string s;
 	s = pd.get_str(section_name, "type");
+	Landscape* ldscp = NULL;
 	if (s=="old_style")
 	{
-		Landscape_old_style* ldscp = new Landscape_old_style();
-		ldscp->load(landscape_file, section_name);
-		return ldscp;
-	} else {   //	if (s=="fisheye")
-		Landscape_fisheye* ldscp = new Landscape_fisheye();
-		ldscp->load(landscape_file, section_name);
-		return ldscp;
+		ldscp = new LandscapeOldStyle();
 	}
+	else if (s=="spherical")
+	{
+		ldscp = new LandscapeSpherical();
+	}
+	else if (s=="fisheye")
+	{
+		ldscp = new LandscapeFisheye();
+	}
+	else
+	{
+		cerr << "Unknown landscape type: " << s << endl;
 
+		// to avoid making this a fatal error, will load as a fisheye
+		// if this fails, it just won't draw
+		ldscp = new LandscapeFisheye();
+	}
+	
+	ldscp->load(landscape_file, section_name);
+	return ldscp;
 }
 
 // create landscape from parameters passed in a hash (same keys as with ini file)
 // NOTE: maptex must be full path and filename
-Landscape* Landscape::create_from_hash(stringHash_t param)
+Landscape* Landscape::create_from_hash(stringHash_t & param)
 {
 
-	// NOTE: textures should be full filename (and path) 
+	// NOTE: textures should be full filename (and path)
 	if (param["type"]=="old_style")
 	{
-		Landscape_old_style* ldscp = new Landscape_old_style();
+		LandscapeOldStyle* ldscp = new LandscapeOldStyle();
 		ldscp->create(1, param);
 		return ldscp;
-	} else {   //	if (s=="fisheye")
-		Landscape_fisheye* ldscp = new Landscape_fisheye();
+	}
+	else if (param["type"]=="spherical")
+	{
+		LandscapeSpherical* ldscp = new LandscapeSpherical();
+		ldscp->create(param["name"], 1, param["path"] + param["maptex"]);
+		return ldscp;
+	}
+	else
+	{   //	if (s=="fisheye")
+		LandscapeFisheye* ldscp = new LandscapeFisheye();
 		ldscp->create(param["name"], 1, param["path"] + param["maptex"], str_to_double(param["texturefov"]));
 		return ldscp;
 	}
 }
 
+// Load attributes common to all landscapes
+void Landscape::loadCommon(const string& landscape_file, const string& section_name)
+{
+	InitParser pd;	// The landscape data ini file parser
+	pd.load(landscape_file);
+	name = pd.get_str(section_name, "name");
+	author = pd.get_str(section_name, "author");
+	description = pd.get_str(section_name, "description");
+	if(name == "" )
+	{
+		cerr << "No valid landscape definition found for section "<< section_name << " in file " << landscape_file << ". No landscape in use." << endl;
+		valid_landscape = 0;
+		return;
+	}
+	else
+	{
+		valid_landscape = 1;
+	}
+}
 
 string Landscape::get_file_content(const string& landscape_file)
 {
-	init_parser pd;	// The landscape data ini file parser
+	InitParser pd;	// The landscape data ini file parser
 	pd.load(landscape_file);
 
 	string result;
@@ -81,13 +120,40 @@ string Landscape::get_file_content(const string& landscape_file)
 	return result;
 }
 
-Landscape_old_style::Landscape_old_style(float _radius) : Landscape(_radius), side_texs(NULL), sides(NULL)
+string Landscape::getLandscapeNames(const string& landscape_file)
 {
+    InitParser pd;	// The landscape data ini file parser
+	pd.load(landscape_file);
+
+	string result;
+
+	for (int i=0; i<pd.get_nsec();i++)
+	{
+        result += pd.get_str(pd.get_secname(i), "name") + '\n';
+	}
+	return result;
 }
 
-Landscape_old_style::~Landscape_old_style()
+string Landscape::nameToKey(const string& landscape_file, const string & name)
 {
-        if (side_texs) {
+    InitParser pd;	// The landscape data ini file parser
+	pd.load(landscape_file);
+
+	for (int i=0; i<pd.get_nsec();i++)
+	{
+        if (name==pd.get_str(pd.get_secname(i), "name")) return pd.get_secname(i);
+	}
+	assert(0);
+	return "error";
+}
+
+LandscapeOldStyle::LandscapeOldStyle(float _radius) : Landscape(_radius), side_texs(NULL), sides(NULL), fog_tex(NULL), ground_tex(NULL)
+{}
+
+LandscapeOldStyle::~LandscapeOldStyle()
+{
+	if (side_texs)
+	{
 		for (int i=0;i<nb_side_texs;++i)
 		{
 			if (side_texs[i]) delete side_texs[i];
@@ -103,20 +169,21 @@ Landscape_old_style::~Landscape_old_style()
 
 }
 
-void Landscape_old_style::load(const string& landscape_file, const string& section_name)
+void LandscapeOldStyle::load(const string& landscape_file, const string& section_name)
 {
+	loadCommon(landscape_file, section_name);
+	
 	// TODO: put values into hash and call create method to consolidate code
 
-	init_parser pd;	// The landscape data ini file parser
+	InitParser pd;	// The landscape data ini file parser
 	pd.load(landscape_file);
 
-	name = pd.get_str(section_name, "name");
-	if(name == "" ) {
-	  printf("ERROR : No valid landscape definition found for %s.  No landscape in use.\n", section_name.c_str());
-	  valid_landscape = 0;
-	  return;
-	} else {
-	  valid_landscape = 1;
+	string type = pd.get_str(section_name, "type");
+	if(type != "old_style")
+	{
+		cerr << "Landscape type mismatch for landscape "<< section_name << ", expected old_style, found " << type << ".  No landscape in use.\n";
+		valid_landscape = 0;
+		return;
 	}
 
 	// Load sides textures
@@ -180,15 +247,8 @@ void Landscape_old_style::load(const string& landscape_file, const string& secti
 
 
 // create from a hash of parameters (no ini file needed)
-void Landscape_old_style::create(bool _fullpath, stringHash_t param)
+void LandscapeOldStyle::create(bool _fullpath, stringHash_t param)
 {
-
-	/*
-	for ( stringHashIter_t iter = param.begin(); iter != param.end(); ++iter ) {
-		cout << iter->first << " : " << iter->second << endl;
-	}
-	*/
-
 	name = param["name"];
 	valid_landscape = 1;  // assume valid if got here
 
@@ -254,7 +314,7 @@ void Landscape_old_style::create(bool _fullpath, stringHash_t param)
 	draw_ground_first = str_to_int(param["draw_ground_first"]);
 }
 
-void Landscape_old_style::draw(tone_reproductor * eye, const Projector* prj, const navigator* nav)
+void LandscapeOldStyle::draw(ToneReproductor * eye, const Projector* prj, const Navigator* nav)
 {
 	if(!valid_landscape) return;
 	if (draw_ground_first) draw_ground(eye, prj, nav);
@@ -265,30 +325,30 @@ void Landscape_old_style::draw(tone_reproductor * eye, const Projector* prj, con
 
 
 // Draw the horizon fog
-void Landscape_old_style::draw_fog(tone_reproductor * eye, const Projector* prj, const navigator* nav) const
+void LandscapeOldStyle::draw_fog(ToneReproductor * eye, const Projector* prj, const Navigator* nav) const
 {
-	if(!fog_fader.get_interstate()) return;
+	if(!fog_fader.getInterstate()) return;
 	glBlendFunc(GL_ONE, GL_ONE);
 	glPushMatrix();
-	glColor3f(fog_fader.get_interstate()*(0.1f+0.1f*sky_brightness), fog_fader.get_interstate()*(0.1f+0.1f*sky_brightness), fog_fader.get_interstate()*(0.1f+0.1f*sky_brightness));
+	glColor3f(fog_fader.getInterstate()*(0.1f+0.1f*sky_brightness), fog_fader.getInterstate()*(0.1f+0.1f*sky_brightness), fog_fader.getInterstate()*(0.1f+0.1f*sky_brightness));
 	glEnable(GL_TEXTURE_2D);
 	glEnable(GL_BLEND);
 	glEnable(GL_CULL_FACE);
 	glBindTexture(GL_TEXTURE_2D, fog_tex->getID());
 	prj->sCylinder(radius, radius*sinf(fog_alt_angle*M_PI/180.), 128, 1, nav->get_local_to_eye_mat() *
-		Mat4d::translation(Vec3d(0.,0.,radius*sinf(fog_angle_shift*M_PI/180.))), 1);
+	               Mat4d::translation(Vec3d(0.,0.,radius*sinf(fog_angle_shift*M_PI/180.))), 1);
 	glDisable(GL_CULL_FACE);
 	glPopMatrix();
 }
 
 // Draw the mountains with a few pieces of texture
-void Landscape_old_style::draw_decor(tone_reproductor * eye, const Projector* prj, const navigator* nav) const
+void LandscapeOldStyle::draw_decor(ToneReproductor * eye, const Projector* prj, const Navigator* nav) const
 {
-	if (!land_fader.get_interstate()) return;
+	if (!land_fader.getInterstate()) return;
 	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 	glEnable(GL_TEXTURE_2D);
 
-	glColor4f(sky_brightness, sky_brightness, sky_brightness, land_fader.get_interstate());
+	glColor4f(sky_brightness, sky_brightness, sky_brightness, land_fader.getInterstate());
 
 	int subdiv = 128/(nb_decor_repeat*nb_side);
 	if (subdiv<=0) subdiv = 1;
@@ -302,11 +362,11 @@ void Landscape_old_style::draw_decor(tone_reproductor * eye, const Projector* pr
 	Mat4d mat = nav->get_local_to_eye_mat();
 	glPushMatrix();
 	glLoadMatrixd(mat);
-	
+
 	z=radius*sinf(decor_angle_shift*M_PI/180.);
 	glEnable(GL_BLEND);
-	glEnable(GL_CULL_FACE);	
-	
+	glEnable(GL_CULL_FACE);
+
 	for (int n=0;n<nb_decor_repeat;++n)
 	{
 		a = 2.f*M_PI*n/nb_decor_repeat;
@@ -320,10 +380,10 @@ void Landscape_old_style::draw_decor(tone_reproductor * eye, const Projector* pr
 				y = radius * cosf(a + da * j + da * subdiv * i + decor_angle_rotatez*M_PI/180);
 				glNormal3f(-x, -y, 0);
 				glTexCoord2f(sides[i].tex_coords[0] + (float)j/subdiv * (sides[i].tex_coords[2]-sides[i].tex_coords[0]),
-					sides[i].tex_coords[3]);
+				             sides[i].tex_coords[3]);
 				prj->sVertex3(x, y, z + dz * (sides[i].tex_coords[3]-sides[i].tex_coords[1]), mat);
 				glTexCoord2f(sides[i].tex_coords[0] + (float)j/subdiv * (sides[i].tex_coords[2]-sides[i].tex_coords[0]),
-					sides[i].tex_coords[1]);
+				             sides[i].tex_coords[1]);
 				prj->sVertex3(x, y, z , mat);
 			}
 			glEnd();
@@ -335,11 +395,11 @@ void Landscape_old_style::draw_decor(tone_reproductor * eye, const Projector* pr
 
 
 // Draw the ground
-void Landscape_old_style::draw_ground(tone_reproductor * eye, const Projector* prj, const navigator* nav) const
+void LandscapeOldStyle::draw_ground(ToneReproductor * eye, const Projector* prj, const Navigator* nav) const
 {
-	if (!land_fader.get_interstate()) return;
+	if (!land_fader.getInterstate()) return;
 	Mat4d mat = nav->get_local_to_eye_mat() * Mat4d::zrotation(ground_angle_rotatez*M_PI/180.f) * Mat4d::translation(Vec3d(0,0,radius*sinf(ground_angle_shift*M_PI/180.)));
-	glColor4f(sky_brightness, sky_brightness, sky_brightness, land_fader.get_interstate());
+	glColor4f(sky_brightness, sky_brightness, sky_brightness, land_fader.getInterstate());
 	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 	glEnable(GL_CULL_FACE);
 	glEnable(GL_TEXTURE_2D);
@@ -351,37 +411,35 @@ void Landscape_old_style::draw_ground(tone_reproductor * eye, const Projector* p
 	glDisable(GL_CULL_FACE);
 }
 
-Landscape_fisheye::Landscape_fisheye(float _radius) : Landscape(_radius), map_tex(NULL)
-{
-}
+LandscapeFisheye::LandscapeFisheye(float _radius) : Landscape(_radius), map_tex(NULL)
+{}
 
-Landscape_fisheye::~Landscape_fisheye()
+LandscapeFisheye::~LandscapeFisheye()
 {
 	if (map_tex) delete map_tex;
 	map_tex = NULL;
 }
 
-void Landscape_fisheye::load(const string& landscape_file, const string& section_name)
+void LandscapeFisheye::load(const string& landscape_file, const string& section_name)
 {
-	init_parser pd;	// The landscape data ini file parser
+	loadCommon(landscape_file, section_name);
+	
+	InitParser pd;	// The landscape data ini file parser
 	pd.load(landscape_file);
 
-	string type;
-	type = pd.get_str(section_name, "type");
-	name = pd.get_str(section_name, "name");
-	if(type != "fisheye" || name == "" ) {
-	  printf("ERROR : No valid landscape definition found for %s.  No landscape in use.\n", section_name.c_str());
-	  valid_landscape = 0;
-	  return;
+	string type = pd.get_str(section_name, "type");
+	if(type != "fisheye")
+	{
+		cerr << "Landscape type mismatch for landscape "<< section_name << ", expected fisheye, found " << type << ".  No landscape in use.\n";
+		valid_landscape = 0;
+		return;
 	}
-
 	create(name, 0, pd.get_str(section_name, "maptex"), pd.get_double(section_name, "texturefov", 360));
-
 }
 
 
 // create a fisheye landscape from basic parameters (no ini file needed)
-void Landscape_fisheye::create(const string _name, bool _fullpath, const string _maptex, double _texturefov)
+void LandscapeFisheye::create(const string _name, bool _fullpath, const string _maptex, double _texturefov)
 {
 	//	cout << _name << " " << _fullpath << " " << _maptex << " " << _texturefov << "\n";
 	valid_landscape = 1;  // assume ok...
@@ -391,15 +449,15 @@ void Landscape_fisheye::create(const string _name, bool _fullpath, const string
 }
 
 
-void Landscape_fisheye::draw(tone_reproductor * eye, const Projector* prj, const navigator* nav)
+void LandscapeFisheye::draw(ToneReproductor * eye, const Projector* prj, const Navigator* nav)
 {
 	if(!valid_landscape) return;
-	if(!land_fader.get_interstate()) return;
+	if(!land_fader.getInterstate()) return;
 
 	// Normal transparency mode
 	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 
-	glColor4f(sky_brightness, sky_brightness, sky_brightness, land_fader.get_interstate());
+	glColor4f(sky_brightness, sky_brightness, sky_brightness, land_fader.getInterstate());
 
 	glEnable(GL_CULL_FACE);
 	glEnable(GL_TEXTURE_2D);
@@ -410,3 +468,80 @@ void Landscape_fisheye::draw(tone_reproductor * eye, const Projector* prj, const
 	glDisable(GL_CULL_FACE);
 }
 
+
+// spherical panoramas
+
+LandscapeSpherical::LandscapeSpherical(float _radius) : Landscape(_radius), map_tex(NULL)
+{}
+
+LandscapeSpherical::~LandscapeSpherical()
+{
+	if (map_tex) delete map_tex;
+	map_tex = NULL;
+}
+
+void LandscapeSpherical::load(const string& landscape_file, const string& section_name)
+{
+	loadCommon(landscape_file, section_name);
+	
+	InitParser pd;	// The landscape data ini file parser
+	pd.load(landscape_file);
+
+	string type = pd.get_str(section_name, "type");
+	if(type != "spherical" )
+	{
+		cerr << "Landscape type mismatch for landscape "<< section_name << ", expected spherical, found " << type << ".  No landscape in use.\n";
+		valid_landscape = 0;
+		return;
+	}
+
+	create(name, 0, pd.get_str(section_name, "maptex"));
+
+}
+
+
+// create a spherical landscape from basic parameters (no ini file needed)
+void LandscapeSpherical::create(const string _name, bool _fullpath, const string _maptex)
+{
+	//	cout << _name << " " << _fullpath << " " << _maptex << " " << _texturefov << "\n";
+	valid_landscape = 1;  // assume ok...
+	name = _name;
+	map_tex = new s_texture(_fullpath,_maptex,TEX_LOAD_TYPE_PNG_ALPHA);
+}
+
+
+void LandscapeSpherical::draw(ToneReproductor * eye, const Projector* prj, const Navigator* nav)
+{
+	if(!valid_landscape) return;
+	if(!land_fader.getInterstate()) return;
+
+	// Need to flip texture usage horizontally due to glusphere convention
+	// so that left-right is consistent in source texture and rendering
+	glMatrixMode(GL_TEXTURE);
+	glPushMatrix();
+	glLoadIdentity();
+	glScalef(-1,1,1);
+	glTranslatef(-1,0,0);
+	glMatrixMode(GL_MODELVIEW);
+
+	// Normal transparency mode
+	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+
+	glColor4f(sky_brightness, sky_brightness, sky_brightness, land_fader.getInterstate());
+
+	glEnable(GL_CULL_FACE);
+	glEnable(GL_TEXTURE_2D);
+	glEnable(GL_BLEND);
+	glBindTexture(GL_TEXTURE_2D, map_tex->getID());
+
+	// TODO: verify that this works correctly for custom projections
+	// seam is at East
+	prj->sSphere(radius,1.0,40,20, nav->get_local_to_eye_mat(), 1);
+
+	glDisable(GL_CULL_FACE);
+
+	glMatrixMode(GL_TEXTURE);
+	glPopMatrix();
+	glMatrixMode(GL_MODELVIEW);
+}
+
