@@ -24,8 +24,7 @@
 #include "SDL.h"
 
 #include "stellarium.h"
-#include "stel_core.h"
-#include "stel_sdl.h"
+#include "stelapp.h"
 
 #if defined(MACOSX) && defined(XCODE)
 #include "StelConfig.h"
@@ -33,31 +32,24 @@
 
 using namespace std;
 
-string DDIR;	// Data Directory
-string TDIR;	// Textures Directory
 string CDIR;	// Config Directory
+string LDIR;	// Locale dir for PO translation files
 string DATA_ROOT;	// Data Root Directory
 
 // Print a beautiful console logo !!
 void drawIntro(void)
 {
-    printf("\n");
-    printf("    -----------------------------------------\n");
-    printf("    | ## ### ### #   #   ### ###  #  # # # #|\n");
-    printf("    | #   #  ##  #   #   ### ##   #  # # ###|\n");
-    printf("    |##   #  ### ### ### # # # #  #  ### # #|\n");
-    printf("    |                       %s|\n",APP_NAME);
-    printf("    -----------------------------------------\n\n");
-    printf("Copyright (C) 2000-2005 Fabien Chereau et al.\n\n");
-    printf(_("Please check last version and send bug report & comments \n\
-on stellarium web page : http://www.stellarium.org\n\n"));
+    cout << " -------------------------------------------------------" << endl;
+    cout << "[ This is "<< APP_NAME << " - http://www.stellarium.org ]" << endl;
+    cout << "[ Copyright (C) 2000-2006 Fabien Chereau et al         ]" << endl;
+    cout << " -------------------------------------------------------" << endl;
 };
 
 
 // Display stellarium usage in the console
 void usage(char **argv)
 {
-	printf(_("Usage: %s [OPTION] ...\n -v, --version          Output version information and exit.\n -h, --help             Display this help and exit.\n"), argv[0]);
+	wcout << _("Usage: %s [OPTION] ...\n -v, --version          Output version information and exit.\n -h, --help             Display this help and exit.\n");
 }
 
 
@@ -69,7 +61,7 @@ void check_command_line(int argc, char **argv)
     {
         if (!(strcmp(argv[1],"--version") && strcmp(argv[1],"-v")))
         {
-            printf("%s\n", APP_NAME);
+            wcout << APP_NAME << endl;
             exit(0);
         }
         if (!(strcmp(argv[1],"--help") && strcmp(argv[1],"-h")))
@@ -81,8 +73,8 @@ void check_command_line(int argc, char **argv)
 
     if (argc > 1)
     {
-        printf(_("%s: Bad command line argument(s)\n"), argv[0]);
-        printf(_("Try `%s --help' for more information.\n"), argv[0]);
+        wcout << _("%s: Bad command line argument(s)\n");
+        wcout << _("Try `%s --help' for more information.\n");
         exit(1);
     }
 }
@@ -124,10 +116,8 @@ void setDirectories(const char* executableName)
 			else
 			{
             	// Failure....
-            	printf(_("ERROR : I can't find the datas directories in :\n\
-%s/ nor in ./ nor in ../\n\
-You may fully install the software (type \"make install\" on POSIX systems)\n\
-or launch the application from the stellarium package directory.\n"),CONFIG_DATA_DIR);
+            	cerr << "ERROR : I can't find the datas directories in :\n"  << CONFIG_DATA_DIR << 
+            	"/ nor in ./ nor in ../\nYou may fully install the software (type \"make install\" on POSIX systems)\nor launch the application from the stellarium package directory." << endl;
                 exit(-1);
 			}
 		}
@@ -146,13 +136,13 @@ or launch the application from the stellarium package directory.\n"),CONFIG_DATA
 #endif
 
 	// We now have a valid dataRoot directory, we can then set the data and textures dir
-	DDIR = DATA_ROOT + "/data/";
-	TDIR = DATA_ROOT + "/textures/";
+	LDIR = LOCALEDIR;
 
 	// If the system is non unix (windows) or if it's macosx the config file is in the
 	// config/ directory of the dataRoot directory
-#if defined(WIN32) || defined(CYGWIN) || defined(__MINGW32__) || defined(MACOSX)
+#if defined(WIN32) || defined(CYGWIN) || defined(__MINGW32__) || defined(MINGW32) || defined(MACOSX)
 	CDIR = DATA_ROOT + "/config/";
+	LDIR = DATA_ROOT + "/data/locale";
 
 	if ((tempFile = fopen((CDIR + "config.ini").c_str(),"r")))
 	{
@@ -161,13 +151,13 @@ or launch the application from the stellarium package directory.\n"),CONFIG_DATA
 	else
 	{
 		// First launch for that user : set default options by copying the default files
-		system( (string("cp ") + CDIR + "default_config.ini " + CDIR + "config.ini").c_str() );
+		system( (string("cp ") + DATA_ROOT + "/data/default_config.ini " + CDIR + "config.ini").c_str() );
 	}
 #else
 
 	// Just an indication if we are on unix/linux that we use local data files
 	if (DATA_ROOT != string(CONFIG_DATA_DIR))
-		printf(_("> Found data files in %s : local version.\n"), DATA_ROOT.c_str());
+		printf("> Found data files in %s : local version.\n", DATA_ROOT.c_str());
 
 	// The problem is more complexe in the case of a unix/linux system
 	// The config files are in the HOME/.stellarium/ directory and this directory
@@ -185,7 +175,7 @@ or launch the application from the stellarium package directory.\n"),CONFIG_DATA
 	}
 	else
 	{
-		printf(_("Will create config files in %s\n"), CDIR.c_str());
+		printf("Will create config files in %s\n", CDIR.c_str());
 		if ((tempFile = fopen((CDIR + "config.ini").c_str(),"w")))
 		{
 			fclose(tempFile);
@@ -193,7 +183,7 @@ or launch the application from the stellarium package directory.\n"),CONFIG_DATA
 		else
 		{
 			// Maybe the directory is not created so try to create it
-			printf(_("Try to create directory %s\n"),CDIR.c_str());
+			printf("Try to create directory %s\n",CDIR.c_str());
 			system(string("mkdir " + CDIR).c_str());
 
 			if ((tempFile = fopen((CDIR + "config.ini").c_str(),"w")))
@@ -202,31 +192,28 @@ or launch the application from the stellarium package directory.\n"),CONFIG_DATA
 			}
 			else
 			{
-				printf(_("Can't create the file %sconfig.ini\n\
-If the directory %s is missing please create it by hand.\n\
-If not, check that you have access to %s\n"), CDIR.c_str(), CDIR.c_str(), CDIR.c_str());
+				cerr << "Can't create the file "<< CDIR << "config.ini\nIf the directory " << 
+				CDIR << " is missing please create it by hand.\nIf not, check that you have access to " <<
+				CDIR << endl;
 				exit(-1);
 			}
 		}
 
 		// First launch for that user : set default options by copying the default files
-		system( (string("cp ") + DATA_ROOT + "/config/default_config.ini " + CDIR + "config.ini").c_str() );
+		system( (string("cp ") + DATA_ROOT + "/data/default_config.ini " + CDIR + "config.ini").c_str() );
 	}
 #endif	// Unix system
 
 #else   // Mac OS X
-    const char *ddir = NULL;
-    const char *tdir = NULL;
     const char *cdir = NULL;
     const char *data_root = NULL;
 
-    if (!setDirectories(&ddir, &tdir, &cdir, &data_root))
+    if (!setDirectories(&cdir, &data_root))
         exit(-1);
 
-    DDIR = ddir;
-    TDIR = tdir;
     CDIR = cdir;
     DATA_ROOT = data_root;
+    LDIR = DATA_ROOT + "/data/locale";
 #endif
 }
 
@@ -235,21 +222,8 @@ If not, check that you have access to %s\n"), CDIR.c_str(), CDIR.c_str(), CDIR.c
 // Main stellarium procedure
 int main(int argc, char **argv)
 {
-
-//Tony - added "&& !defined(WIN32)"
-#if !defined(MACOSX) && !defined(WIN32)
-	// TESTING ONLY
-	// setenv("LC_ALL", "fr_FR", 1);
-
-	setlocale (LC_CTYPE, "");
-	setlocale (LC_MESSAGES, "");
-	bindtextdomain (PACKAGE, LOCALEDIR);
-	textdomain (PACKAGE);
-
-	// TODO: move to utf8
-	bind_textdomain_codeset(PACKAGE, "iso-8859-1");
-
-#endif
+	// Used for getting system date formatting
+	setlocale(LC_TIME, "");
 	
 	// Check the command line
 	check_command_line(argc, argv);
@@ -260,39 +234,14 @@ int main(int argc, char **argv)
 	// Find what are the main Data, Textures and Config directories
     setDirectories(argv[0]);
 
-	// Create the core of stellarium, it has to be initialized
-	stel_core* core = new stel_core(DDIR, TDIR, CDIR, DATA_ROOT);
+	StelApp* app = new StelApp(CDIR, LDIR, DATA_ROOT);
 
-	// Give the config file parameters which has to be given "hard coded"
-#if !defined(MACOSX) && !defined(XCODE)
-	core->set_config_files("config.ini");
-#else
-    core->set_config_files(STELLARIUM_CONF_FILE);
-#endif
+	app->init();
 
-	// Load the configuration options from the given file names
-	// This includes the video parameters
-	core->load_config();
-
-	// Create a stellarium sdl manager
-	stel_sdl sdl_mgr(core);
-
-	// Initialize video device and other sdl parameters
-	sdl_mgr.init();
-
-	core->init();
-
-    // Tony - added Re-load of config to re-enable flags available once the core has loaded 
-	core->load_config();
-
-	// play startup script, if available
-	core->play_startup_script();
-
-	// Start the main loop until the end of the execution
-	sdl_mgr.start_main_loop();
+	app->startMainLoop();
 
 	// Clean memory
-	delete core;
+	delete app;
 
 	return 0;
 }
