@@ -31,7 +31,7 @@ which are generally not at the apex of the Earth's way, such as the Perseids sho
 #include <cstdlib>
 #include "meteor.h"
 
-Meteor::Meteor(Projector *proj, navigator* nav, tone_reproductor* eye, double v)
+Meteor::Meteor(Projector *proj, Navigator* nav, ToneReproductor* eye, double v)
 {
   //  velocity = 11+(double)rand()/((double)RAND_MAX+1)*v;  // abs range 11-72 km/s
   velocity=v;
@@ -192,7 +192,7 @@ bool Meteor::update(int delta_time)
 
 
 // returns true if visible
-bool Meteor::draw(Projector *proj, navigator* nav)
+bool Meteor::draw(Projector *proj, Navigator* nav)
 {
 
 	if(!alive) return(0);
@@ -244,7 +244,7 @@ bool Meteor::draw(Projector *proj, navigator* nav)
 		glVertex3f(start[0],start[1],0);
 		glEnd();
 	} else {
-		glPointSize(1);
+		//glPointSize(1); // glpoint is not portable...
 		glBegin(GL_POINTS);
 		glVertex3f(start[0],start[1],0);
 		glEnd();
