@@ -24,12 +24,11 @@
 #include "stellarium.h"
 
 string s_texture::texDir = "./";
-string s_texture::suffix = "";
 
 s_texture::s_texture(const string& _textureName) : textureName(_textureName), texID(0),
 	loadType(PNG_BLEND1), loadType2(GL_CLAMP)
 {
-    load( texDir + textureName + suffix );
+    load( texDir + textureName );
 }
 
 
@@ -52,9 +51,28 @@ s_texture::s_texture(bool full_path, const string& _textureName, int _loadType)
     texID=0;
 	whole_path = full_path;
 	if(full_path) load(textureName);
-	else load( texDir + textureName + suffix );
+	else load( texDir + textureName );
 }
 
+s_texture::s_texture(const s_texture &t) {
+  textureName = t.textureName;
+  loadType = t.loadType;
+  loadType2 = t.loadType2;
+  whole_path = t.whole_path;
+  texID=0;
+  load(texDir + textureName);
+}
+
+const s_texture &s_texture::operator=(const s_texture &t) {
+  unload();
+  textureName = t.textureName;
+  loadType = t.loadType;
+  loadType2 = t.loadType2;
+  whole_path = t.whole_path;
+  texID=0;
+  load(texDir + textureName);
+  return *this;
+}
 
 s_texture::s_texture(const string& _textureName, int _loadType) : textureName(_textureName),
 	texID(0), loadType(PNG_BLEND1), loadType2(GL_CLAMP_TO_EDGE)
@@ -72,7 +90,7 @@ s_texture::s_texture(const string& _textureName, int _loadType) : textureName(_t
         default : loadType=PNG_BLEND3;
     }
     texID=0;
-    load( texDir + textureName + suffix );
+    load( texDir + textureName );
 }
 
 s_texture::~s_texture()
@@ -86,14 +104,26 @@ int s_texture::load(string fullName)
     FILE * tempFile = fopen(fullName.c_str(),"r");
     if (!tempFile)
 	{
-		cout << "WARNING : Can't find texture file " << fullName << "!" << endl;
+		cerr << "WARNING : Can't find texture file " << fullName << "!" << endl;
 		return 0;
 	}
 	fclose(tempFile);
 
     pngInfo info;
     pngSetStandardOrientation(1);
-    texID = pngBind(fullName.c_str(), PNG_BUILDMIPMAPS, loadType, &info, loadType2, GL_LINEAR, GL_LINEAR);
+
+	// TODO: make mipmap use an argument to this method so not hard coded here
+	// frans van hoesel: hack to filter textures, except stars
+	if (strstr(fullName.c_str(),"star16x16.png") == NULL) {
+		texID = pngBind(fullName.c_str(), PNG_BUILDMIPMAPS,
+						loadType, &info, loadType2,
+						GL_LINEAR_MIPMAP_NEAREST, GL_LINEAR);
+	} else {
+		texID = pngBind(fullName.c_str(), PNG_BUILDMIPMAPS,
+						loadType, &info, loadType2,
+						GL_NEAREST, GL_LINEAR);
+	}
+		
 
 	return (texID!=0);
 }
@@ -107,7 +137,7 @@ int s_texture::reload()
 {
     unload();
 	if(whole_path) return load(textureName);
-	else return load( texDir + textureName + suffix );
+	else return load( texDir + textureName );
 }
 
 // Return the texture size in pixels
