@@ -46,6 +46,8 @@ public:
     s_texture(bool full_path, const string& _textureName, int _loadType);
     s_texture(const string& _textureName, int _loadType);
     virtual ~s_texture();
+    s_texture(const s_texture &t);
+    const s_texture &operator=(const s_texture &t);
     int load(string fullName);
     void unload();
     int reload();
@@ -55,7 +57,6 @@ public:
     int getSize(void) const;
     void getDimensions(int &width, int &height) const;
     static void set_texDir(const string& _texDir) {s_texture::texDir = _texDir;}
-    static void set_suffix(const string& _suffix) {s_texture::suffix = _suffix;}
 
 private:
     string textureName;
@@ -63,7 +64,6 @@ private:
     int loadType;
     int loadType2;
 	static string texDir;
-	static string suffix;
 	bool whole_path;
 };
 
