@@ -34,11 +34,11 @@ typedef struct {
 	float color[3];			// 3 component color, can be RGB or CIE color system
 	} skylight_struct2;
 
-class skylight
+class Skylight
 {
 public:
-    skylight();
-    virtual ~skylight();
+    Skylight();
+    virtual ~Skylight();
 	// Set the fixed parameters and precompute what can be
 	// This funtion has to be called once before any call to get_*_value()
     void set_params(float sun_zenith_angle, float turbidity);
@@ -50,7 +50,7 @@ public:
 	// Same functions but in vector mode : faster because prevents extra cosine calculations
 	// The position vectors MUST be normalized, and the vertical z component is the third one
 	void set_paramsv(const float * sun_pos, float turbidity);
-	void get_xyY_valuev(skylight_struct2 * position);
+	void get_xyY_valuev(skylight_struct2& position);
 
 private:
 	float thetas;			// angular distance between the zenith and the sun in radian
