@@ -18,7 +18,7 @@
  */
 
 //	Class which compute and display the daylight sky color using openGL
-//	the sky is computed with the skylight class.
+//	the sky is computed with the Skylight class.
 
 // TODO : Adaptative resolution for optimization
 
@@ -27,7 +27,7 @@
 #include "stellastro.h"
 #include "stel_atmosphere.h"
 
-stel_atmosphere::stel_atmosphere() : sky_resolution(48), tab_sky(NULL), world_adaptation_luminance(0.f), atm_intensity(0)
+Atmosphere::Atmosphere() : sky_resolution(48), tab_sky(NULL), world_adaptation_luminance(0.f), atm_intensity(0)
 {
 	// Create the vector array used to store the sky color on the full field of view
 	tab_sky = new Vec3f*[sky_resolution+1];
@@ -35,10 +35,10 @@ stel_atmosphere::stel_atmosphere() : sky_resolution(48), tab_sky(NULL), world_ad
 	{
 		tab_sky[k] = new Vec3f[sky_resolution+1];
 	}
-	set_fade_duration(3.f);
+	setFadeDuration(3.f);
 }
 
-stel_atmosphere::~stel_atmosphere()
+Atmosphere::~Atmosphere()
 {
 	for (int k=0; k<sky_resolution+1 ;k++)
 	{
@@ -47,15 +47,15 @@ stel_atmosphere::~stel_atmosphere()
 	if (tab_sky) delete [] tab_sky;
 }
 
-void stel_atmosphere::compute_color(double JD, Vec3d sunPos, Vec3d moonPos, float moon_phase,
-	tone_reproductor * eye, Projector* prj,
-	float latitude, float altitude, float temperature, float relative_humidity)
+void Atmosphere::compute_color(double JD, Vec3d sunPos, Vec3d moonPos, float moon_phase,
+                               ToneReproductor * eye, Projector* prj,
+                               float latitude, float altitude, float temperature, float relative_humidity)
 {
 
 	float min_mw_lum = 0.13;
 
 	// no need to calculate if not visible
-	if(!fader.get_interstate())
+	if(!fader.getInterstate())
 	{
 		atm_intensity = 0;
 		world_adaptation_luminance = 3.75f;
@@ -64,10 +64,10 @@ void stel_atmosphere::compute_color(double JD, Vec3d sunPos, Vec3d moonPos, floa
 	}
 	else
 	{
-		atm_intensity = fader.get_interstate();
+		atm_intensity = fader.getInterstate();
 	}
 
-	
+
 	//Vec3d obj;
 	skylight_struct2 b2;
 
@@ -90,19 +90,22 @@ void stel_atmosphere::compute_color(double JD, Vec3d sunPos, Vec3d moonPos, floa
 	// TODO: correct for atmospheric diffusion
 	// TODO: use better coverage function (non-linear)
 	// because of above issues, this algorithm darkens more quickly than reality
-	if( separation_angle < touch_angle) {
+	if( separation_angle < touch_angle)
+	{
 		float min;
-		if(dark_angle < 0) {
+		if(dark_angle < 0)
+		{
 			// annular eclipse
 			float asun = sun_angular_size*sun_angular_size;
 			min = (asun - moon_angular_size*moon_angular_size)/asun;  // minimum proportion of sun uncovered
 			dark_angle *= -1;
-		} else min = 0.004;  // so bright stars show up at total eclipse
+		}
+		else min = 0.004;  // so bright stars show up at total eclipse
 
 		if(separation_angle < dark_angle) atm_intensity = min;
 		else atm_intensity *= min + (1.-min)*(separation_angle-dark_angle)/(touch_angle-dark_angle);
 
-		//		printf("atm int %f (min %f)\n", atm_intensity, min);		
+		//		printf("atm int %f (min %f)\n", atm_intensity, min);
 	}
 
 	float sun_pos[3];
@@ -126,10 +129,10 @@ void stel_atmosphere::compute_color(double JD, Vec3d sunPos, Vec3d moonPos, floa
 
 	skyb.set_date(date.years, date.months, moon_phase);
 
-	float stepX = (float)prj->viewW() / sky_resolution;
-	float stepY = (float)prj->viewH() / sky_resolution;
-	float viewport_left = (float)prj->view_left();
-	float viewport_bottom = (float)prj->view_bottom();
+	float stepX = (float)prj->getViewportWidth() / sky_resolution;
+	float stepY = (float)prj->getViewportHeight() / sky_resolution;
+	float viewport_left = (float)prj->getViewportPosX();
+	float viewport_bottom = (float)prj->getViewportPosY();
 
 	Vec3d point(1., 0., 0.);
 
@@ -156,19 +159,19 @@ void stel_atmosphere::compute_color(double JD, Vec3d sunPos, Vec3d moonPos, floa
 			b2.pos[1] = point[1];
 			b2.pos[2] = point[2];
 
-			// Use the skylight model for the color
-			sky.get_xyY_valuev(&b2);
+			// Use the Skylight model for the color
+			sky.get_xyY_valuev(b2);
 
-			// Use the skybright.cpp 's models for brightness which gives better results.
+			// Use the Skybright.cpp 's models for brightness which gives better results.
 			b2.color[2] = skyb.get_luminance(moon_pos[0]*b2.pos[0]+moon_pos[1]*b2.pos[1]+
-					moon_pos[2]*b2.pos[2], sun_pos[0]*b2.pos[0]+sun_pos[1]*b2.pos[1]+
-					sun_pos[2]*b2.pos[2], b2.pos[2]);
+			                                 moon_pos[2]*b2.pos[2], sun_pos[0]*b2.pos[0]+sun_pos[1]*b2.pos[1]+
+			                                 sun_pos[2]*b2.pos[2], b2.pos[2]);
 
 
 			sum_lum+=b2.color[2];
 			++nb_lum;
 			eye->xyY_to_RGB(b2.color);
-			tab_sky[x][y].set(b2.color[0],b2.color[1],b2.color[2]);
+			tab_sky[x][y].set(atm_intensity*b2.color[0],atm_intensity*b2.color[1],atm_intensity*b2.color[2]);
 		}
 	}
 
@@ -182,36 +185,33 @@ void stel_atmosphere::compute_color(double JD, Vec3d sunPos, Vec3d moonPos, floa
 
 
 // Draw the atmosphere using the precalc values stored in tab_sky
-void stel_atmosphere::draw(Projector* prj, int delta_time)
+void Atmosphere::draw(Projector* prj, int delta_time)
 {
-	if(fader.get_interstate())
+	if(fader.getInterstate())
 	{
+		// printf("Atm int: %f\n", atm_intensity);
+		glBlendFunc(GL_ONE, GL_ONE_MINUS_SRC_COLOR);
 
-	  // printf("Atm int: %f\n", atm_intensity);
-	  glBlendFunc(GL_ONE, GL_ONE_MINUS_SRC_COLOR);
+		float stepX = (float)prj->getViewportWidth() / sky_resolution;
+		float stepY = (float)prj->getViewportHeight() / sky_resolution;
+		float viewport_left = (float)prj->getViewportPosX();
+		float view_bottom = (float)prj->getViewportPosY();
 
-	  float stepX = (float)prj->viewW() / sky_resolution;
-	  float stepY = (float)prj->viewH() / sky_resolution;
-	  float viewport_left = (float)prj->view_left();
-	  float view_bottom = (float)prj->view_bottom();
-
-	  glDisable(GL_TEXTURE_2D);
-	  glEnable(GL_BLEND);
-	  prj->set_orthographic_projection();	// set 2D coordinate
-	  for (int y2=0; y2<sky_resolution; ++y2)
-	    {
-	      glBegin(GL_QUAD_STRIP);
-	      for(int x2=0; x2<sky_resolution+1; ++x2)
+		glDisable(GL_TEXTURE_2D);
+		glEnable(GL_BLEND);
+		prj->set_orthographic_projection();	// set 2D coordinate
+		for (int y2=0; y2<sky_resolution; ++y2)
 		{
-		  glColor3f(atm_intensity*tab_sky[x2][y2][0],atm_intensity*tab_sky[x2][y2][1],
-			    atm_intensity*tab_sky[x2][y2][2]);
-		  glVertex2i((int)(viewport_left+x2*stepX),(int)(view_bottom+y2*stepY));
-		  glColor3f(atm_intensity*tab_sky[x2][y2+1][0],atm_intensity*tab_sky[x2][y2+1][1],
-			    atm_intensity*tab_sky[x2][y2+1][2]);
-		  glVertex2i((int)(viewport_left+x2*stepX),(int)(view_bottom+(y2+1)*stepY));
+			glBegin(GL_QUAD_STRIP);
+			for(int x2=0; x2<sky_resolution+1; ++x2)
+			{
+				glColor3fv(tab_sky[x2][y2]);
+				glVertex2i((int)(viewport_left+x2*stepX),(int)(view_bottom+y2*stepY));
+				glColor3fv(tab_sky[x2][y2+1]);
+				glVertex2i((int)(viewport_left+x2*stepX),(int)(view_bottom+(y2+1)*stepY));
+			}
+			glEnd();
 		}
-	      glEnd();
-	    }
-	  prj->reset_perspective_projection();
+		prj->reset_perspective_projection();
 	}
 }
