@@ -24,14 +24,15 @@
 #include "s_texture.h"
 #include "planet.h"
 
-s_texture * stel_object::pointer_star = NULL;
-s_texture * stel_object::pointer_planet = NULL;
-s_texture * stel_object::pointer_nebula = NULL;
+s_texture * StelObject::pointer_star = NULL;
+s_texture * StelObject::pointer_planet = NULL;
+s_texture * StelObject::pointer_nebula = NULL;
+s_texture * StelObject::pointer_telescope = NULL;
 
-int stel_object::local_time = 0;
+int StelObject::local_time = 0;
 
 // Draw a nice animated pointer around the object
-void stel_object::draw_pointer(int delta_time, const Projector* prj, const navigator * nav)
+void StelObject::draw_pointer(int delta_time, const Projector* prj, const Navigator * nav)
 {
 	local_time+=delta_time;
 	Vec3d pos=get_earth_equ_pos(nav);
@@ -43,19 +44,26 @@ void stel_object::draw_pointer(int delta_time, const Projector* prj, const navig
 	if (get_type()==STEL_OBJECT_NEBULA) glColor3f(0.4f,0.5f,0.8f);
 	if (get_type()==STEL_OBJECT_PLANET) glColor3f(1.0f,0.3f,0.3f);
 
-    if (get_type()==STEL_OBJECT_STAR)
+    if (get_type()==STEL_OBJECT_STAR||get_type()==STEL_OBJECT_TELESCOPE)
     {
 		glColor3fv(get_RGB());
-		glBindTexture (GL_TEXTURE_2D, pointer_star->getID());
+		float radius;
+		if (get_type()==STEL_OBJECT_STAR) {
+			radius = 13.f;
+			glBindTexture (GL_TEXTURE_2D, pointer_star->getID());
+		} else {
+			radius = 25.f;
+			glBindTexture (GL_TEXTURE_2D, pointer_telescope->getID());
+		}
         glEnable(GL_TEXTURE_2D);
         glEnable(GL_BLEND);
         glTranslatef(screenpos[0], screenpos[1], 0.0f);
         glRotatef((float)local_time/20.,0.,0.,1.);
         glBegin(GL_QUADS );
-            glTexCoord2f(0.0f,0.0f);    glVertex3f(-13.,-13.,0.);      //Bas Gauche
-            glTexCoord2f(1.0f,0.0f);    glVertex3f(13.,-13.,0.);       //Bas Droite
-            glTexCoord2f(1.0f,1.0f);    glVertex3f(13.,13.,0.);        //Haut Droit
-            glTexCoord2f(0.0f,1.0f);    glVertex3f(-13.,13.,0.);       //Haut Gauche
+            glTexCoord2f(0.0f,0.0f);    glVertex3f(-radius,-radius,0.);      //Bas Gauche
+            glTexCoord2f(1.0f,0.0f);    glVertex3f(radius,-radius,0.);       //Bas Droite
+            glTexCoord2f(1.0f,1.0f);    glVertex3f(radius,radius,0.);        //Haut Droit
+            glTexCoord2f(0.0f,1.0f);    glVertex3f(-radius,radius,0.);       //Haut Gauche
         glEnd ();
     }
 
@@ -115,27 +123,19 @@ void stel_object::draw_pointer(int delta_time, const Projector* prj, const navig
     prj->reset_perspective_projection();
 }
 
-//! Write information about the object in char* s 
-void stel_object::get_info_string(char * s, const navigator * nav) const
+
+void StelObject::init_textures(void)
 {
-	sprintf(s,"No info for this object...");
+	pointer_star = new s_texture("pointeur2.png");
+	pointer_planet = new s_texture("pointeur4.png");
+	pointer_nebula = new s_texture("pointeur5.png");
+	pointer_telescope = new s_texture("pointeur2.png");
 }
 
-void stel_object::get_short_info_string(char * s, const navigator * nav) const
-{
-	sprintf(s,"No info");
-}
-
-void stel_object::init_textures(void)
-{
-	pointer_star = new s_texture("pointeur2");
-	pointer_planet = new s_texture("pointeur4");
-	pointer_nebula = new s_texture("pointeur5");
-}
-
-void stel_object::delete_textures(void)
+void StelObject::delete_textures(void)
 {
 	delete pointer_star; pointer_star = NULL;
 	delete pointer_planet; pointer_planet = NULL;
 	delete pointer_nebula; pointer_nebula = NULL;
+	delete pointer_telescope; pointer_telescope = NULL;
 }
