@@ -16,28 +16,21 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-#include "stel_sdl.h"
+#ifdef WIN32
+#include "shlobj.h"
+#endif
+
+#include "stelapp.h"
+#include "s_gui.h"
 
 #ifdef HAVE_SDL_MIXER_H
 #include "SDL_mixer.h"
 #endif
 
-stel_sdl::stel_sdl(stel_core * _core)
-{
-	if (!_core)
-	{
-		printf("ERROR : In stel_sdl constructor, unvalid core.");
-		exit(-1);
-	}
-	core = _core;
-}
+using namespace s_gui;
 
-stel_sdl::~stel_sdl()
-{
-  SDL_FreeCursor(Cursor);
-}
 
-void stel_sdl::init(void)
+void StelApp::initSDL(int w, int h, int bbpMode, bool fullScreen, string iconFile)
 {
     Uint32	Vflags;		// Our Video Flags
     Screen = NULL;
@@ -46,14 +39,14 @@ void stel_sdl::init(void)
 
     // Init the SDL library, the VIDEO subsystem    
     // Tony - added timer
-    if(SDL_Init(SDL_INIT_VIDEO |  SDL_INIT_AUDIO | SDL_INIT_NOPARACHUTE | SDL_INIT_TIMER)<0)
+    if(SDL_Init(SDL_INIT_VIDEO | SDL_INIT_AUDIO | SDL_INIT_NOPARACHUTE | SDL_INIT_TIMER)<0)
 	{
 		// couldn't init audio, so try without
-		printf("Unable to open SDL with audio: %s\n", SDL_GetError() );
+		fprintf(stderr, "Error: unable to open SDL with audio: %s\n", SDL_GetError() );
 
-		if(SDL_Init(SDL_INIT_VIDEO | SDL_INIT_NOPARACHUTE)<0)
+		if(SDL_Init(SDL_INIT_VIDEO | SDL_INIT_NOPARACHUTE | SDL_INIT_TIMER)<0)
 		{
-			printf("Unable to open SDL: %s\n", SDL_GetError() );
+			fprintf(stderr, "Error: unable to open SDL: %s\n", SDL_GetError() );
 			exit(-1);
 		}
     } 
@@ -71,9 +64,9 @@ void stel_sdl::init(void)
 	}
 #else
 	// SDL_mixer is not available - no audio
-	if(SDL_Init(SDL_INIT_VIDEO | SDL_INIT_NOPARACHUTE)<0)
+	if(SDL_Init(SDL_INIT_VIDEO | SDL_INIT_NOPARACHUTE | SDL_INIT_TIMER)<0)
 	{
-		printf("Unable to open SDL: %s\n", SDL_GetError() );
+		fprintf(stderr, "Unable to open SDL: %s\n", SDL_GetError() );
 		exit(-1);
 	}
 #endif
@@ -88,34 +81,28 @@ void stel_sdl::init(void)
     Vflags = SDL_HWSURFACE|SDL_OPENGL;//|SDL_DOUBLEBUF;
 	SDL_GL_SetAttribute(SDL_GL_STENCIL_SIZE,1);
 	// If fullscreen, set the Flag
-    if (core->get_Fullscreen()) Vflags|=SDL_FULLSCREEN;
+    if (fullScreen) Vflags|=SDL_FULLSCREEN;
 
 	// Create the SDL screen surface
-    Screen = SDL_SetVideoMode(core->get_screen_W(), core->get_screen_H(), core->get_bppMode(), Vflags);
+    Screen = SDL_SetVideoMode(w, h, bbpMode, Vflags);
 	if(!Screen)
 	{
-		printf("sdl: Couldn't set %dx%d video mode (%s), retrying with stencil size 0\n",
- 		core->get_screen_W(), core->get_screen_H(), SDL_GetError());
-
+		printf("Warning: Couldn't set %dx%d video mode (%s), retrying with stencil size 0\n", w, h, SDL_GetError());
 		SDL_GL_SetAttribute(SDL_GL_STENCIL_SIZE,0);
-		Screen = SDL_SetVideoMode(core->get_screen_W(), core->get_screen_H(), core->get_bppMode(), Vflags);
+		Screen = SDL_SetVideoMode(w, h, bbpMode, Vflags);
 
 		if(!Screen)
 		{
-			printf("sdl: Couldn't set %dx%d video mode: %s!\n",
-			core->get_screen_W(), core->get_screen_H(), SDL_GetError());
+			fprintf(stderr, "Error: Couldn't set %dx%d video mode: %s!\n", w, h, SDL_GetError());
 			exit(-1);
 		}	
 	}
 
 	// Disable key repeat
     SDL_EnableKeyRepeat(0, 0);
-
 	SDL_EnableUNICODE(1);
 
-
 	// set mouse cursor 
-/* XPM */
 static const char *arrow[] = {
   /* width height num_colors chars_per_pixel */
   "    32    32        3            1",
@@ -159,14 +146,14 @@ static const char *arrow[] = {
   "15,17"
 };
 
- Cursor = create_cursor(arrow);
- SDL_SetCursor(Cursor);
+	Cursor = create_cursor(arrow);
+	SDL_SetCursor(Cursor);
 
 	// Set the window caption
 	SDL_WM_SetCaption(APP_NAME, APP_NAME);
 
 	// Set the window icon
-	SDL_Surface *icon = SDL_LoadBMP((core->get_DataDir() + "icon.bmp").c_str());
+	SDL_Surface *icon = SDL_LoadBMP((iconFile).c_str());
 	SDL_WM_SetIcon(icon, NULL);
 	SDL_FreeSurface(icon);
 	
@@ -175,9 +162,34 @@ static const char *arrow[] = {
 	glClear(GL_COLOR_BUFFER_BIT);	
 }
 
+string StelApp::getVideoModeList(void) const
+{
+    SDL_Rect **modes;
+	int i;
+	/* Get available fullscreen/hardware modes */
+	modes=SDL_ListModes(NULL, SDL_FULLSCREEN|SDL_HWSURFACE);
+	/* Check is there are any modes available */
+	if(modes == (SDL_Rect **)0)
+	{
+		return "No modes available!\n";
+	}
+	/* Check if our resolution is restricted */
+	if(modes == (SDL_Rect **)-1)
+	{
+		return "All resolutions available.\n";
+	}
+	else
+	{
+		/* Print valid modes */
+		ostringstream modesstr;
+		for(i=0;modes[i];++i)
+			modesstr << modes[i]->w << "x" << modes[i]->h << endl;
+		return modesstr.str();
+	}
+}
 
 // from an sdl wiki
-SDL_Cursor* stel_sdl::create_cursor(const char *image[])
+SDL_Cursor* StelApp::create_cursor(const char *image[])
 {
   int i, row, col;
   Uint8 data[4*32];
@@ -213,7 +225,7 @@ SDL_Cursor* stel_sdl::create_cursor(const char *image[])
 
 
 // Terminate the application
-void TerminateApplication(void)
+void StelApp::terminateApplication(void)
 {
 	static SDL_Event Q;						// Send a SDL_QUIT event
 	Q.type = SDL_QUIT;						// To the SDL event queue
@@ -224,10 +236,36 @@ void TerminateApplication(void)
 	}
 }
 
-void stel_sdl::start_main_loop(void)
+enum {
+	USER_EVENT_TICK
+};
+
+
+Uint32 mytimer_callback(Uint32 interval, void *param)
+{
+	SDL_Event event;
+	event.type = SDL_USEREVENT;
+	event.user.type = SDL_USEREVENT;
+	event.user.code = USER_EVENT_TICK;
+	event.user.data1 = NULL;
+	event.user.data2 = NULL;
+	if(SDL_PushEvent(&event) == -1)
+	{
+		printf("User tick event can't be pushed: %s\n", SDL_GetError() );
+		exit(-1);
+	}
+
+	// End this timer.
+	return 0;
+}
+
+void StelApp::start_main_loop()
 {
     bool AppVisible = true;			// At The Beginning, Our App Is Visible
     enum S_GUI_VALUE bt;
+    Uint32 last_event_time = SDL_GetTicks();
+    // How fast the objects on-screen are moving, in pixels/millisecond.
+    double animationSpeed = 0;
 
     // Hold the value of SDL_GetTicks at start of main loop (set 0 time)
     LastCount = SDL_GetTicks();
@@ -237,6 +275,10 @@ void stel_sdl::start_main_loop(void)
 	{
 		if(SDL_PollEvent(&E))	// Fetch The First Event Of The Queue
 		{
+			if (E.type != SDL_USEREVENT) {
+				last_event_time = SDL_GetTicks();
+			}
+
 			switch(E.type)		// And Processing It
 			{
 				case SDL_QUIT:
@@ -245,7 +287,7 @@ void stel_sdl::start_main_loop(void)
 
 				case SDL_VIDEORESIZE:
 					// Recalculate The OpenGL Scene Data For The New Window
-					resize_GL(E.resize.w, E.resize.h);
+					if (E.resize.h && E.resize.w) core->setViewportSize(E.resize.w, E.resize.h);
 					break;
 
 				case SDL_ACTIVEEVENT:
@@ -258,7 +300,7 @@ void stel_sdl::start_main_loop(void)
 					break;
 
 				case SDL_MOUSEMOTION:
-				  	core->handle_move(E.motion.x,E.motion.y);
+				  	handleMove(E.motion.x,E.motion.y);
 					break;
 				
 				case SDL_MOUSEBUTTONDOWN:
@@ -272,7 +314,7 @@ void stel_sdl::start_main_loop(void)
 						case SDL_BUTTON_WHEELDOWN : bt=S_GUI_MOUSE_WHEELDOWN; break;
 						default : bt=S_GUI_MOUSE_LEFT;
 					}
-					core->handle_clic(E.button.x,E.button.y,bt,S_GUI_PRESSED);
+					handleClick(E.button.x,E.button.y,bt,S_GUI_PRESSED);
 					break;
 
 				case SDL_MOUSEBUTTONUP:
@@ -286,28 +328,23 @@ void stel_sdl::start_main_loop(void)
 						case SDL_BUTTON_WHEELDOWN : bt=S_GUI_MOUSE_WHEELDOWN; break;
 						default : bt=S_GUI_MOUSE_LEFT;
 					}
-					core->handle_clic(E.button.x,E.button.y,bt,S_GUI_RELEASED);
+					handleClick(E.button.x,E.button.y,bt,S_GUI_RELEASED);
 					break;
 
 				case SDL_KEYDOWN:
 					// Send the event to the gui and stop if it has been intercepted
-
-					/*
-					printf("key pressed: ");
-					if( E.key.keysym.unicode < 0x80 && E.key.keysym.unicode > 0 ){
-						printf( "%c (0x%04X)\n", (char)E.key.keysym.unicode,
-								E.key.keysym.unicode );
-					}
-					else{
-						printf( "? (0x%04X)\n", E.key.keysym.unicode );
-					}
-					*/
-
 					// use unicode translation, since not keyboard dependent
 					// however, for non-printing keys must revert to just keysym... !
-					if ((E.key.keysym.unicode && !core->handle_keys(E.key.keysym.unicode,S_GUI_PRESSED)) ||
-						(!E.key.keysym.unicode && !core->handle_keys(E.key.keysym.sym,S_GUI_PRESSED)))
+					if ((E.key.keysym.unicode && !handleKeys(E.key.keysym.sym,E.key.keysym.mod,E.key.keysym.unicode,S_GUI_PRESSED)) ||
+						(!E.key.keysym.unicode && !handleKeys(E.key.keysym.sym,E.key.keysym.mod,E.key.keysym.sym,S_GUI_PRESSED)))
 					{
+
+						/* Fumio patch... can't use because ignores unicode values and hence is US keyboard specific.
+						   - what was the reasoning?
+					if ((E.key.keysym.sym >= SDLK_LAST && !core->handle_keys(E.key.keysym.unicode,S_GUI_PRESSED)) ||
+						(E.key.keysym.sym < SDLK_LAST && !core->handle_keys(E.key.keysym.sym,S_GUI_PRESSED)))
+						*/
+
 						if (E.key.keysym.sym==SDLK_F1) SDL_WM_ToggleFullScreen(Screen); // Try fullscreen
 
 						// ctrl-s saves screenshot
@@ -343,14 +380,27 @@ void stel_sdl::start_main_loop(void)
 							free(pixels);
 
 							string shotdir;
-#if defined(WIN32) || defined(CYGWIN) || defined(__MINGW32__)
-							if(getenv("USERPROFILE")!=NULL){
-								//for Win XP etc.
-								shotdir = string(getenv("USERPROFILE")) + "\\My Documents\\";
-							}else{
-								//for Win 98 etc.
-								shotdir = "C:\\My Documents\\";
+#if defined(WIN32)
+							char path[MAX_PATH];
+							path[MAX_PATH-1] = '\0';
+							if (SUCCEEDED(SHGetFolderPath(NULL, CSIDL_DESKTOPDIRECTORY, NULL, 0, path)))
+							{
+								shotdir = string(path)+"\\";
 							}
+							else
+							{	
+								if(getenv("USERPROFILE")!=NULL)
+								{
+									//for Win XP etc.
+									shotdir = string(getenv("USERPROFILE")) + "\\My Documents\\";
+								}
+								else
+								{
+									//for Win 98 etc.
+									shotdir = "C:\\My Documents\\";
+								}
+							}
+
 #else
 							shotdir = string(getenv("HOME")) + "/";
 #endif
@@ -376,11 +426,11 @@ void stel_sdl::start_main_loop(void)
 
 					}
 					// Rescue escape in case of lock : CTRL + ESC forces brutal quit
-					if (E.key.keysym.sym==SDLK_ESCAPE && (SDL_GetModState() & KMOD_CTRL)) TerminateApplication();
+					if (E.key.keysym.sym==SDLK_ESCAPE && (SDL_GetModState() & KMOD_CTRL)) terminateApplication();
 					break;
 
 				case SDL_KEYUP:
-					core->handle_keys(E.key.keysym.sym,S_GUI_RELEASED);
+					handleKeys(E.key.keysym.sym,E.key.keysym.mod,E.key.keysym.sym,S_GUI_RELEASED);
 			}
 		}
 		else  // No events to poll
@@ -393,27 +443,45 @@ void stel_sdl::start_main_loop(void)
 			}
 			else
 			{
+				// Compute how many fps we should run at to get 1 pixel movement each frame.
+				double frameRate = 1000. * animationSpeed;
+				// If there was user action in the last 2.5 seconds, shoot for the max framerate.
+				if (SDL_GetTicks() - last_event_time < 2500 || frameRate > maxfps)
+				{
+					frameRate = maxfps;
+				}
+				if (frameRate < minfps)
+				{
+					frameRate = minfps;
+				}
 
 				TickCount = SDL_GetTicks();			// Get present ticks
-				// This is used to constraint the maximum FPS rate
-				if (TickCount-LastCount < 1000.f/core->getMaxFPS())
+				// Wait a while if drawing a frame right now would exceed our preferred framerate.
+				if (TickCount-LastCount < 1000./frameRate)
 				{
-					SDL_Delay((unsigned int)(1000.f/core->getMaxFPS())-(TickCount-LastCount));
+					unsigned int delay = (unsigned int) (1000./frameRate) - (TickCount-LastCount);
+//					printf("delay=%d\n", delay);
+					if (delay < 15) {
+						// Less than 15ms, just do a dumb wait.
+						SDL_Delay(delay);
+					} else {
+						// A longer delay. Use this timer song and dance so
+						// that the app is still responsive if the user does something.
+						if (!SDL_AddTimer(delay, mytimer_callback, NULL))
+						{
+							cerr << "Error: couldn't create an SDL timer: " << SDL_GetError() << endl;
+						}
+						SDL_WaitEvent(NULL);
+					}
 				}
+
 				TickCount = SDL_GetTicks();			// Get present ticks
-				core->update(TickCount-LastCount);	// And update the motions and data
-				core->draw(TickCount-LastCount);	// Do the drawings!
+				this->update(TickCount-LastCount);	// And update the motions and data
+				double squaredDistance = this->draw(TickCount-LastCount);	// Do the drawings!
+				animationSpeed = sqrt(squaredDistance) / (TickCount-LastCount);
 				LastCount = TickCount;				// Save the present tick probing
 				SDL_GL_SwapBuffers();				// And swap the buffers
 			}
 		}
 	}
 }
-
-
-void stel_sdl::resize_GL(int w, int h)
-{
-    if (!h || !w) return;
-	core->set_screen_size(w, h);
-}
-
