@@ -50,11 +50,11 @@
 
 #include "fmath.h"
 
-class tone_reproductor
+class ToneReproductor
 {
 public:
-    tone_reproductor();
-    virtual ~tone_reproductor();
+    ToneReproductor();
+    virtual ~ToneReproductor();
 
 	// Set the eye adaptation luminance for the display (and precompute what can be)
 	// Usual luminance range is 1-100 cd/m^2 for a CRT screen
@@ -62,7 +62,7 @@ public:
 	void set_display_adaptation_luminance(float display_adaptation_luminance);
 
 	// Set the eye adaptation luminance for the world (and precompute what can be)
-	// default value = 40000 cd/m^2 for skylight
+	// default value = 40000 cd/m^2 for Skylight
 	// Star Light      : 0.001  cd/m^2
 	// Moon Light      : 0.1    cd/m^2
 	// Indoor Lighting : 100    cd/m^2
@@ -71,15 +71,15 @@ public:
 
 	// Set the maximum display luminance : default value = 100 cd/m^2
 	// This value is used to scale the RGB range
-	void set_max_display_luminance(float _MaxdL) {MaxdL = MaxdL;}
+	void set_max_display_luminance(float maxdL) {one_over_maxdL = 1.f/maxdL;}
 
 	// Set the display gamma : default value = 2.3
-	void set_display_gamma(float _gamma) {gamma = _gamma;}
+	void set_display_gamma(float gamma) {one_over_gamma = 1.f/gamma;}
 
 	// Return adapted luminance from world to display
 	float adapt_luminance(float world_luminance) const
 	{
-		return powf((float)(world_luminance*M_PI*0.0001f),alpha_wa_over_alpha_da) * term2;
+		return powf(world_luminance*M_PI*0.0001f,alpha_wa_over_alpha_da) * term2;
 	}
 
 	// Convert from xyY color system to RGB
@@ -88,8 +88,8 @@ public:
 private:
 	float Lda;		// Display luminance adaptation (in cd/m^2)
 	float Lwa;		// World   luminance adaptation (in cd/m^2)
-	float MaxdL;	// Display maximum luminance (in cd/m^2)
-	float gamma;	// Screen gamma value
+	float one_over_maxdL;	// 1 / Display maximum luminance (in cd/m^2)
+	float one_over_gamma;	// 1 / Screen gamma value
 
 	// Precomputed variables
 	float alpha_da;
