@@ -27,6 +27,7 @@
 #include <cmath>
 #include <cstring>
 #include <cstdio>
+#include <iostream>
 
 template<class T> class Vector2;
 template<class T> class Vector3;
@@ -35,6 +36,7 @@ template<class T> class Matrix4;
 
 typedef Vector2<float>	Vec2f;
 typedef Vector2<int>	Vec2i;
+typedef Vector2<size_t> Vec2size_t;
 
 typedef Vector3<float>	Vec3f;
 typedef Vector3<double>	Vec3d;
@@ -211,6 +213,7 @@ template<class T> class Matrix4
     inline Matrix4 operator*(const Matrix4<T>&) const;
 
     inline Vector3<T> operator*(const Vector3<T>&) const;
+    inline Vector3<T> multiplyWithoutTranslation(const Vector3<T>& a) const;
 	inline Vector4<T> operator*(const Vector4<T>&) const;
 
     static Matrix4<T> identity();
@@ -542,6 +545,12 @@ template<class T> void Vector3<T>::transfo4d(const Mat4f& m)
 	(*this)=m*(*this);
 }
 
+template<class T> 
+std::ostream& operator<<(std::ostream &o,const Vector3<T> &v) {
+  return o << '[' << v[0] << ',' << v[1] << ',' << v[2] << ']';
+}
+
+
 ////////////////////////// Vector4 class methods ///////////////////////////////
 
 template<class T> Vector4<T>::Vector4()
@@ -694,6 +703,11 @@ template<class T> void Vector4<T>::transfo4d(const Mat4d& m)
 	(*this)=m*(*this);
 }
 
+template<class T> 
+std::ostream& operator<<(std::ostream &o,const Vector4<T> &v) {
+  return o << '[' << v[0] << ',' << v[1] << ',' << v[2] << ',' << v[3] << ']';
+}
+
 
 ////////////////////////// Matrix4 class methods ///////////////////////////////
 
@@ -879,6 +893,13 @@ template<class T> Vector3<T> Matrix4<T>::operator*(const Vector3<T>& a) const
 						r[2]*a.v[0] + r[6]*a.v[1] + r[10]*a.v[2] + r[14] );
 }
 
+template<class T> Vector3<T> Matrix4<T>::multiplyWithoutTranslation(const Vector3<T>& a) const
+{
+    return Vector3<T>(	r[0]*a.v[0] + r[4]*a.v[1] +  r[8]*a.v[2],
+						r[1]*a.v[0] + r[5]*a.v[1] +  r[9]*a.v[2],
+						r[2]*a.v[0] + r[6]*a.v[1] + r[10]*a.v[2] );
+}
+
 // multiply column vector by a 4x4 matrix in homogeneous coordinate (considere a[3]=1)
 template<class T> Vector4<T> Matrix4<T>::operator*(const Vector4<T>& a) const
 {
@@ -1107,8 +1128,46 @@ template<class T> Matrix4<T> Matrix4<T>::inverse() const
 
 template<class T> void Matrix4<T>::print(void) const
 {
-	printf("[%.2lf %.2lf %.2lf %.2lf]\n[%.2lf %.2lf %.2lf %.2lf]\n[%.2lf %.2lf %.2lf %.2lf]\n[%.2lf %.2lf %.2lf %.2lf]\n",
-	r[0],r[4],r[8],r[12],r[1],r[5],r[9],r[13],r[2],r[6],r[10],r[14],r[3],r[7],r[11],r[15]);
+    printf("[%5.2lf %5.2lf %5.2lf %17.12le]\n"
+           "[%5.2lf %5.2lf %5.2lf %17.12le]\n"
+           "[%5.2lf %5.2lf %5.2lf %17.12le]\n"
+           "[%5.2lf %5.2lf %5.2lf %17.12le]\n\n",
+    r[0],r[4],r[8],r[12],
+    r[1],r[5],r[9],r[13],
+    r[2],r[6],r[10],r[14],
+    r[3],r[7],r[11],r[15]);
 }
 
+
+template<class T> inline
+T operator*(const Vector2<T>&a,const Vector2<T>&b) {
+  return a.v[0] * b.v[0] + a.v[1] * b.v[1];
+}
+
+template<class T> inline
+T operator*(const Vector3<T>&a,const Vector3<T>&b) {
+  return a.v[0] * b.v[0] + a.v[1] * b.v[1] + a.v[2] * b.v[2];
+}
+
+template<class T> inline
+T operator*(const Vector4<T>&a,const Vector4<T>&b) {
+  return a.v[0]*b.v[0] + a.v[1]*b.v[1] + a.v[2]*b.v[2] + a.v[3]*b.v[3];
+}
+
+template<class T> inline
+Vector2<T> operator*(T s,const Vector2<T>&v) {
+  return Vector2<T>(s*v[0],s*v[1]);
+}
+
+template<class T> inline
+Vector3<T> operator*(T s,const Vector3<T>&v) {
+  return Vector3<T>(s*v[0],s*v[1],s*v[2]);
+}
+
+template<class T> inline
+Vector4<T> operator*(T s,const Vector4<T>&v) {
+  return Vector4<T>(s*v[0],s*v[1],s*v[2],s*v[3]);
+}
+
+
 #endif // _VECMATH_H_
